@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol;
 
@@ -12,6 +31,8 @@ import java.io.File;
 import java.io.FileReader;
 import java.io.IOException;
 import java.util.Locale;
+import java.util.jar.Attributes;
+import java.util.jar.Manifest;
 import java.util.logging.Handler;
 import java.util.logging.Level;
 import java.util.logging.Logger;
@@ -49,9 +70,6 @@ import net.sf.freecol.server.FreeColServer;
 */
 public final class FreeCol {
     
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2986 $";
 
     public static final String  META_SERVER_ADDRESS = "meta.freecol.org";
     public static final int     META_SERVER_PORT = 3540;
@@ -68,7 +86,8 @@ public final class FreeCol {
      */
     private static Specification specification;
 
-    private static final String FREECOL_VERSION = "0.7.2";
+    private static final String FREECOL_VERSION = "0.7.4";
+    private static String FREECOL_REVISION;
     
     private static final String MIN_JDK_VERSION = "1.5";
     private static final String FILE_SEP = System.getProperty("file.separator");
@@ -109,6 +128,17 @@ public final class FreeCol {
      * @param args The command-line arguments.
      */
     public static void main(String[] args) {
+
+        try {
+            Manifest manifest = new Manifest(FreeCol.class.getResourceAsStream("/META-INF/MANIFEST.MF"));
+            Attributes attribs = manifest.getMainAttributes();
+            String revision = attribs.getValue("Revision");
+            FREECOL_REVISION = FREECOL_VERSION + " (Revision: " + revision + ")";
+        } catch (Exception e) {
+            System.out.println("Unable to load Manifest.");
+            FREECOL_REVISION = FREECOL_VERSION;
+        }
+
         initLogging();
         
         // Display splash screen:
@@ -129,6 +159,7 @@ public final class FreeCol {
         handleArgs(args);
         
         if (javaCheck && !checkJavaVersion()) {
+            removeSplash(splash);
             System.err.println("Java version " + MIN_JDK_VERSION +
                             " or better is recommended in order to run FreeCol." +
                             " Use --no-java-check to skip this check.");
@@ -137,6 +168,7 @@ public final class FreeCol {
 
         int  minMemory = 128;  // million bytes
         if (memoryCheck && Runtime.getRuntime().maxMemory() < minMemory * 1000000) {
+            removeSplash(splash);
             System.out.println("You need to assign more memory to the JVM. Restart FreeCol with:");
             System.out.println("java -Xmx" + minMemory + "M -jar FreeCol.jar");
             return;
@@ -163,6 +195,7 @@ public final class FreeCol {
                         
                         freeColServer = new FreeColServer(savegameFile, defaultPublicServer, defaultSingleplayer, serverPort, serverName);
                     } catch (Exception e) {
+                        removeSplash(splash);
                         System.out.println("Could not load savegame.");
                         return;
                     }
@@ -170,6 +203,7 @@ public final class FreeCol {
                     try {
                         freeColServer = new FreeColServer(true, false, serverPort, serverName);
                     } catch (NoRouteToServerException e) {
+                        removeSplash(splash);
                         System.out.println(Messages.message("server.noRouteToServer"));
                         System.exit(1);
                         return;
@@ -183,6 +217,7 @@ public final class FreeCol {
                     }
                 });
             } catch (IOException e) {
+                removeSplash(splash);
                 System.err.println("Error while loading server: " + e);
                 System.exit(-1);
             }
@@ -205,6 +240,7 @@ public final class FreeCol {
             } catch (UnsupportedLookAndFeelException e) {
                 logger.warning("Could not load the \"FreeCol Look and Feel\"");
             } catch (FreeColException e) {
+                removeSplash(splash);
                 e.printStackTrace();
                 System.out.println("\nThe data files could not be found by FreeCol. Please make sure");
                 System.out.println("they are present. If FreeCol is looking in the wrong directory");
@@ -222,6 +258,7 @@ public final class FreeCol {
             try {
                 lib = new ImageLibrary(dataFolder);
             } catch (FreeColException e) {
+                removeSplash(splash);
                 e.printStackTrace();
                 System.out.println("\nThe data files could not be found by FreeCol. Please make sure");
                 System.out.println("they are present. If FreeCol is looking in the wrong directory");
@@ -260,16 +297,13 @@ public final class FreeCol {
             }
         }
         
-        if (splash != null) {
-            splash.setVisible(false);
-            splash.dispose();
-        }
+        removeSplash(splash);
     }
 
     /**
      * Displays a splash screen.
      * @return The splash screen. It should be removed by the caller
-     *      when no longer needed.
+     *      when no longer needed by a call to removeSplash().
      */
     private static JWindow displaySplash(String filename) {
         try {
@@ -286,6 +320,16 @@ public final class FreeCol {
             return null;
         }
     }
+
+    /**
+     * Removes splash screen.
+     */
+    private static void removeSplash(JWindow splash) {
+        if (splash != null) {
+            splash.setVisible(false);
+            splash.dispose();
+        }
+    }
     
     /**
      * Initialize loggers.
@@ -521,6 +565,19 @@ public final class FreeCol {
                 }
                 
                 windowed = true;
+            } else if (args[i].length() > 16 && args[i].substring(0, 16).equals("--default-locale")) {
+                if (args[i].charAt(16) == '=') {
+                    // slightly ugly: strip encoding from LC_MESSAGES
+                    String languageID = args[i].substring(17);
+                    int index = languageID.indexOf('.');
+                    if (index > 0) {
+                        languageID = languageID.substring(0, index);
+                    }
+                    Locale.setDefault(LanguageOption.getLocale(languageID));
+                } else {
+                    printUsage();
+                    System.exit(0);
+                }
             } else if (args[i].equals("--no-sound")) {
                 sound = false;
             } else if (args[i].equals("--no-memory-check")) {
@@ -599,6 +656,14 @@ public final class FreeCol {
         return FREECOL_VERSION;
     }
 
+    /**
+     * Gets the current revision of game.
+     *
+     * @return The current version and SVN Revision of the game.
+     */
+    public static String getRevision() {
+        return FREECOL_REVISION;
+    }
 
     /**
     * Checks if the program is in "Debug mode".
@@ -655,6 +720,8 @@ public final class FreeCol {
         System.out.println("  runs FreeCol in windowed mode instead of full screen mode");
         System.out.println("--load-savegame SAVEGAME_FILE");
         System.out.println("  loads the given savegame.");
+        System.out.println("--default-locale=LANGUAGE[_COUNTRY[_VARIANT]]");
+        System.out.println("  sets the default locale.");
         System.out.println("--splash[=SPLASH_IMAGE_FILE]");
         System.out.println("  displays a splash screen while loading the game");
         System.out.println("--no-sound");
