@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.client;
 
@@ -15,6 +34,7 @@ import net.sf.freecol.common.option.IntegerOption;
 import net.sf.freecol.common.option.LanguageOption;
 import net.sf.freecol.common.option.OptionGroup;
 import net.sf.freecol.common.option.OptionMap;
+import net.sf.freecol.common.option.RangeOption;
 import net.sf.freecol.common.option.SelectOption;
 
 import org.w3c.dom.Element;
@@ -33,15 +53,20 @@ public class ClientOptions extends OptionMap {
     @SuppressWarnings("unused")
     private static final Logger logger = Logger.getLogger(ClientOptions.class.getName());
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2701 $";
 
     /**
      * Option for setting the language.
      */
     public static final String LANGUAGE = "languageOption";
-    
+
+    /**
+     * If this option is enabled, the display will recenter in order
+     * to display the active unit if it is not {@link net.sf.freecol.client.gui.GUI#onScreen(Map.Position)}).
+     * 
+     * @see net.sf.freecol.client.gui.GUI
+     */
+    public static final String JUMP_TO_ACTIVE_UNIT = "jumpToActiveUnit";
+
     /**
      * Selected tiles always gets centered if this option is
      * enabled (even if the tile is {@link net.sf.freecol.client.gui.GUI#onScreen(Map.Position)}).
@@ -103,6 +128,7 @@ public class ClientOptions extends OptionMap {
     public static final String SHOW_MARKET_PRICES = "guiShowMarketPrices";
     public static final String SHOW_LOST_CITY_RUMOURS = "guiShowLostCityRumours";
     public static final String SHOW_MISSING_GOODS = "guiShowMissingGoods";
+    public static final String SHOW_TUTORIAL = "guiShowTutorial";
     public static final String SHOW_COLONY_WARNINGS = "guiShowColonyWarnings";
     public static final String SHOW_PRECOMBAT = "guiShowPreCombat";
     
@@ -199,6 +225,11 @@ public class ClientOptions extends OptionMap {
                             COLONY_COMPARATOR_SIZE = 3,
                             COLONY_COMPARATOR_SOL = 4;
 
+    /**
+     * If enabled: Automatically ends the turn when no units can be made active.
+     */
+    public static final String AUTO_END_TURN = "autoEndTurn";
+    
     /**
      * Comparators for sorting colonies.
      */
@@ -338,6 +369,7 @@ public class ClientOptions extends OptionMap {
         new IntegerOption(MIN_NUMBER_FOR_DISPLAYING_GOODS_COUNT, guiGroup, 0, 10, 7);
         new IntegerOption(MAX_NUMBER_OF_GOODS_IMAGES, guiGroup, 1, 10, 7);
         new BooleanOption(ALWAYS_CENTER, guiGroup, false);
+        new BooleanOption(JUMP_TO_ACTIVE_UNIT, guiGroup, true);
         new BooleanOption(DISPLAY_FOG_OF_WAR, guiGroup, false);
         new BooleanOption(MAP_SCROLL_ON_DRAG, guiGroup, true);
         new BooleanOption(DISPLAY_COMPASS_ROSE, guiGroup, false);
@@ -359,7 +391,7 @@ public class ClientOptions extends OptionMap {
         
         OptionGroup minimapGroup = new OptionGroup("clientOptions.minimap");
         new BooleanOption(SMOOTH_MINIMAP_RENDERING, minimapGroup, false);
-        new SelectOption(DEFAULT_MINIMAP_ZOOM, minimapGroup,
+        new RangeOption(DEFAULT_MINIMAP_ZOOM, minimapGroup,
                          new String[] {"1", "2", "3", "4", "5"}, 2, true);
 
         guiGroup.add(minimapGroup);
@@ -380,6 +412,7 @@ public class ClientOptions extends OptionMap {
         new BooleanOption(SHOW_MISSING_GOODS, messagesGroup, true);
         new BooleanOption(SHOW_COLONY_WARNINGS, messagesGroup, true);
         new BooleanOption(SHOW_PRECOMBAT, messagesGroup, true);
+        new BooleanOption(SHOW_TUTORIAL, messagesGroup, true);
         add(messagesGroup);
         
         OptionGroup savegamesGroup = new OptionGroup("clientOptions.savegames");
@@ -400,6 +433,7 @@ public class ClientOptions extends OptionMap {
 
         OptionGroup otherGroup = new OptionGroup("clientOptions.other");
         new BooleanOption(AUTOLOAD_EMIGRANTS, otherGroup, false);
+        new BooleanOption(AUTO_END_TURN, otherGroup, true);
         add(otherGroup);
 
     }
