@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client;
 
 import java.awt.Dimension;
@@ -41,6 +60,7 @@ import net.sf.freecol.common.model.Player;
 import net.sf.freecol.common.networking.Message;
 import net.sf.freecol.common.option.LanguageOption;
 import net.sf.freecol.common.option.Option;
+import net.sf.freecol.common.option.LanguageOption.Language;
 import net.sf.freecol.server.FreeColServer;
 
 import org.w3c.dom.Element;
@@ -52,11 +72,8 @@ import org.w3c.dom.Element;
 public final class FreeColClient {
     private static final Logger logger = Logger.getLogger(FreeColClient.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2988 $";
 
     // Control:
     private ConnectController connectController;
@@ -126,7 +143,7 @@ public final class FreeColClient {
 
     /**
      * Indicated whether or not there is an open connection to the server. This
-     * is not an indication of the existance of a Connection Object, but instead
+     * is not an indication of the existence of a Connection Object, but instead
      * it is an indication of an approved login to a server.
      */
     private boolean loggedIn = false;
@@ -182,12 +199,13 @@ public final class FreeColClient {
             Option o = clientOptions.getObject(ClientOptions.LANGUAGE);
             o.addPropertyChangeListener(new PropertyChangeListener() {
                 public void propertyChange(PropertyChangeEvent e) {
-                    if (((Integer) e.getNewValue()).intValue() == 0) {
+                    if (((Language) e.getNewValue()).getKey().equals(LanguageOption.AUTO)) {
                         canvas.showInformationMessage("autodetectLanguageSelected");
                     } else {
-                        Locale l = LanguageOption.getLocale(((Integer) e.getNewValue()).intValue());
+                        Locale l = ((Language) e.getNewValue()).getLocale();
                         Messages.setMessageBundle(l);
-                        canvas.showInformationMessage("newLanguageSelected", new String[][] {{"%language%", l.getDisplayName()}});
+                        canvas.showInformationMessage("newLanguageSelected",
+                                                      new String[][] {{"%language%", l.getDisplayName()}});
                     }
                 }
             });
@@ -234,6 +252,8 @@ public final class FreeColClient {
         canvas = new Canvas(this, innerWindowSize, gui);
         changeWindowedMode(windowed);
         
+        frame.setIconImage(imageLibrary.getUnitImage(ImageLibrary.GALLEON));
+        
         canvas.showMainPanel();
         gui.startCursorBlinking();
     }
@@ -719,3 +739,4 @@ public final class FreeColClient {
         private static final int VALUES_PER_CALL = 100;
     }
 }
+
