@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.control;
 
 import java.lang.reflect.InvocationTargetException;
@@ -13,6 +32,7 @@ import net.sf.freecol.common.model.DiplomaticTrade;
 import net.sf.freecol.common.model.FoundingFather;
 import net.sf.freecol.common.model.FreeColGameObject;
 import net.sf.freecol.common.model.Goods;
+import net.sf.freecol.common.model.Location;
 import net.sf.freecol.common.model.LostCityRumour;
 import net.sf.freecol.common.model.Map;
 import net.sf.freecol.common.model.ModelMessage;
@@ -34,11 +54,8 @@ import org.w3c.dom.NodeList;
 public final class InGameInputHandler extends InputHandler {
     private static final Logger logger = Logger.getLogger(InGameInputHandler.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2825 $";
 
 
     /**
@@ -212,7 +229,7 @@ public final class InGameInputHandler extends InputHandler {
                 return null;
             }
             if (unit.getTile() == null) {
-                logger.warning("Ignoring opponentMove, unit " + unit.getID() + " has no tile!");
+                logger.warning("Ignoring opponentMove, unit " + unit.getId() + " has no tile!");
                 return null;
             }
 
@@ -373,7 +390,10 @@ public final class InGameInputHandler extends InputHandler {
         }
 
         if (colony != null) {
-            colony.bombard(defender, result);
+        	String repairInRef = opponentAttackElement.getAttribute("repairIn");
+        	Location repairIn = (Location) getGame().getFreeColGameObjectSafely(repairInRef);
+        	
+            colony.bombard(defender, result,repairIn);
         } else {
             unit.attack(defender, result, plunderGold);
             if (!unit.isDisposed() && (unit.getLocation() == null || !unit.isVisibleTo(getFreeColClient().getMyPlayer()))) {
@@ -588,7 +608,7 @@ public final class InGameInputHandler extends InputHandler {
         Settlement settlement = tile.getSettlement();
         if (settlement == null) {
             throw new IllegalArgumentException("No settlement on 'Tile' " +
-                                               tile.getID());
+                                               tile.getId());
         }
         
         NodeList childElements = element.getChildNodes();
@@ -606,7 +626,7 @@ public final class InGameInputHandler extends InputHandler {
                 if (agreement.isAccept()) {
                     diplomaticElement.setAttribute("accept", "accept");
                 } else {
-                    diplomaticElement.setAttribute("unit", unit.getID());
+                    diplomaticElement.setAttribute("unit", unit.getId());
                     diplomaticElement.setAttribute("direction", String.valueOf(direction));
                     diplomaticElement.appendChild(agreement.toXMLElement(null, diplomaticElement.getOwnerDocument()));
                 }
@@ -730,6 +750,18 @@ public final class InGameInputHandler extends InputHandler {
                 }
             }
             return reply;
+        case Monarch.LOWER_TAX:
+        	
+            final int newTax = new Integer(element.getAttribute("amount")).intValue();
+            final int difference = freeColClient.getMyPlayer().getTax() - newTax;
+            
+            logger.info("Waiving taxes from " + String.valueOf(freeColClient.getMyPlayer().getTax()) + " to " +  String.valueOf(newTax));
+            freeColClient.getMyPlayer().setTax(newTax);
+            player.addModelMessage(new ModelMessage(player, "model.monarch.lowerTax",
+                    new String[][] {{"%difference%",String.valueOf(difference)},{"%newTax%",String.valueOf(newTax)}},
+                    ModelMessage.WARNING));
+            break;
+            
         case Monarch.ADD_TO_REF:
             Element arrayElement = Message.getChildElement(element, "addition");
             int[] units = new int[Integer.parseInt(arrayElement.getAttribute("xLength"))];
@@ -1447,7 +1479,7 @@ public final class InGameInputHandler extends InputHandler {
          * 
          * @param unit The unit which init the negotiation.
          * @param settlement The settlement where the unit has made the proposal
-         * @param unit The proposal made by unit's owner.
+         * @param proposal The proposal made by unit's owner.
          */
         public ShowNegotiationDialogSwingTask(Unit unit, Settlement settlement, DiplomaticTrade proposal) {
             this.unit = unit;
