@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui;
 
 import java.awt.Component;
@@ -33,10 +52,11 @@ import javax.swing.UIManager;
 import javax.swing.filechooser.FileFilter;
 import javax.swing.plaf.basic.BasicInternalFrameUI;
 
+import net.sf.freecol.client.ClientOptions;
 import net.sf.freecol.client.FreeColClient;
-import net.sf.freecol.client.gui.action.ActionManager;
 import net.sf.freecol.client.gui.action.MapControlsAction;
 import net.sf.freecol.client.gui.i18n.Messages;
+import net.sf.freecol.client.gui.panel.AboutPanel;
 import net.sf.freecol.client.gui.panel.ChatPanel;
 import net.sf.freecol.client.gui.panel.ChooseFoundingFatherDialog;
 import net.sf.freecol.client.gui.panel.ClientOptionsDialog;
@@ -91,6 +111,7 @@ import net.sf.freecol.common.model.DiplomaticTrade;
 import net.sf.freecol.common.model.Europe;
 import net.sf.freecol.common.model.FreeColGameObject;
 import net.sf.freecol.common.model.Game;
+import net.sf.freecol.common.model.GameVariables;
 import net.sf.freecol.common.model.Goods;
 import net.sf.freecol.common.model.IndianSettlement;
 import net.sf.freecol.common.model.LostCityRumour;
@@ -130,16 +151,13 @@ import net.sf.freecol.server.generator.MapGeneratorOptions;
  * <br>
  * When displaying a dialog, using a <code>showXXXDialog</code>, the calling
  * thread will wait until that dialog is dismissed before returning. In
- * contrast, a <code>showXXXPanel</code>-method returns immediatly.
+ * contrast, a <code>showXXXPanel</code>-method returns immediately.
  */
 public final class Canvas extends JDesktopPane {
     private static final Logger logger = Logger.getLogger(Canvas.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2998 $";
 
     private static final Integer MAIN_LAYER = JLayeredPane.DEFAULT_LAYER;
 
@@ -166,6 +184,8 @@ public final class Canvas extends JDesktopPane {
     private final StatusPanel statusPanel;
 
     private final ChatPanel chatPanel;
+    
+    private final AboutPanel aboutPanel;
 
     private final GUI gui;
 
@@ -222,6 +242,7 @@ public final class Canvas extends JDesktopPane {
         victoryPanel = new VictoryPanel(this, freeColClient);
         clientOptionsDialog = new ClientOptionsDialog(this, freeColClient);
         loadingSavegameDialog = new LoadingSavegameDialog(this, freeColClient);
+        aboutPanel = new AboutPanel(this, freeColClient);
 
         setFocusable(true);
         setFocusTraversalKeysEnabled(false);
@@ -313,7 +334,7 @@ public final class Canvas extends JDesktopPane {
             if (jMenuBar != null) {
                 jMenuBar.setSize(getWidth(), (int) jMenuBar.getPreferredSize().getHeight());
             }
-            MapControlsAction mca = (MapControlsAction) freeColClient.getActionManager().getFreeColAction(MapControlsAction.ID);
+            MapControlsAction mca = (MapControlsAction) freeColClient.getActionManager().getFreeColAction(MapControlsAction.id);
             MapControls mc = mca.getMapControls();
             if (mc != null && mc.isShowing()) {
                 mc.removeFromComponent(this);
@@ -327,6 +348,7 @@ public final class Canvas extends JDesktopPane {
                 }
             }
             gui.setSize(getSize());
+            gui.forceReposition();
             oldSize = getSize();
         }
     }
@@ -376,6 +398,17 @@ public final class Canvas extends JDesktopPane {
             startGamePanel.initialize(singlePlayerMode);
             addAsFrame(startGamePanel);
             startGamePanel.requestFocus();
+            
+            if (freeColClient.getClientOptions().getBoolean(ClientOptions.SHOW_TUTORIAL)) {
+                String[][] data = {
+                    {"%menu_first%", Messages.message("menuBar.game")},
+                    {"%menu_second%", Messages.message("menuBar.game.preferences")},
+                    {"%menu_third%", Messages.message("clientOptions.messages.name")}};
+                if (!showConfirmDialog("tutorial.text", "tutorial.yes", "tutorial.no", data)) {
+                    freeColClient.getClientOptions().setBoolean(ClientOptions.SHOW_TUTORIAL, false);
+                    freeColClient.saveClientOptions();
+                }
+            }
         } else {
             logger.warning("Tried to open 'StartGamePanel' without having 'game' and/or 'player' set.");
         }
@@ -445,12 +478,29 @@ public final class Canvas extends JDesktopPane {
         return offer;
     }
 
+    /**
+     * Displays the <code>AboutPanel</code>.
+     * 
+     * @see AboutPanel
+     */
+    public void showAboutPanel() {
+        closeMenus();
+        addAsFrame(aboutPanel);
+        aboutPanel.requestFocus();
+    }
+    
     /**
      * Displays the <code>ChatPanel</code>.
      * 
      * @see ChatPanel
      */
     public void showChatPanel() {
+    	
+    	// in single player, no chat available
+    	if(freeColClient.isSingleplayer()){
+    		return;
+    	}
+    	
         closeMenus();
         addAsFrame(chatPanel);
         chatPanel.requestFocus();
@@ -823,11 +873,11 @@ public final class Canvas extends JDesktopPane {
         String[] texts = new String[messages.length];
         ImageIcon[] images = new ImageIcon[messages.length];
         for (int i = 0; i < messages.length; i++) {
-            String ID = messages[i].getMessageID();
+            String id = messages[i].getMessageID();
             try {
-                texts[i] = Messages.message(ID);
+                texts[i] = Messages.message(id);
             } catch (MissingResourceException e) {
-                logger.warning("could not find message with id: " + ID + ".");
+                logger.warning("could not find message with id: " + id + ".");
             }
             images[i] = getImageIcon(messages[i].getDisplay(), false);
         }
@@ -1501,6 +1551,28 @@ public final class Canvas extends JDesktopPane {
             f.setSize(getWidth(), getHeight() - getMenuBarHeight());
             f.setLocation(0, getMenuBarHeight());
             f.moveToBack();
+            
+            // BEGIN TUTORIAL
+            final Player player = freeColClient.getMyPlayer();
+            final GameVariables gv = freeColClient.getGame().getGameVariables();
+            if (gv != null && gv.getBoolean(GameVariables.TUTORIAL_SELL_GOODS)) {
+                Unit ship = null;
+                for (Unit u : freeColClient.getMyPlayer().getEurope().getUnitList()) {
+                    if (u.isNaval()) {
+                        ship = u;
+                        break;
+                    }
+                }
+                if (ship != null && ship.getGoodsCount() > 0) {
+                    freeColClient.getInGameController().storeGameVariable(GameVariables.TUTORIAL_SELL_GOODS, false);
+                    final String[][] data = new String[][] {
+                            {"%newLand%", player.getNewLandName()},
+                    };
+                    player.addModelMessage(new ModelMessage(player, "tutorial.sellGoods", data, ModelMessage.TUTORIAL, player));
+                    freeColClient.getInGameController().nextModelMessage();
+                }
+            }
+            // END TUTORIAL
         }
     }
 
@@ -1606,6 +1678,67 @@ public final class Canvas extends JDesktopPane {
         colonyPanel.initialize(colony, freeColClient.getGame());
         addAsFrame(colonyPanel);
         colonyPanel.requestFocus();
+         
+        // BEGIN TUTORIAL
+        final Player player = freeColClient.getMyPlayer();
+        GameVariables gv = freeColClient.getGame().getGameVariables();
+        if (gv != null && gv.getBoolean(GameVariables.TUTORIAL_EQUIP_COLONIST)) {
+            final Tile colonyTile = colony.getTile();
+            boolean unitOnShip = false;
+            boolean unitOnTile = false;
+            Unit unit = null;
+            for (Unit u : colonyTile.getUnitList()) {
+                if (u.isNaval() && u.getUnitList().size() > 0) {
+                    unitOnShip = true;
+                    unit = u.getUnitList().get(0);
+                }
+                if (!u.isNaval()) {
+                    unitOnTile = true;
+                    unit = u;
+                }
+            }
+            if (unitOnShip || unitOnTile) {
+                freeColClient.getInGameController().storeGameVariable(GameVariables.TUTORIAL_SECOND_COLONIST, false);
+                freeColClient.getInGameController().storeGameVariable(GameVariables.TUTORIAL_EQUIP_COLONIST, false);
+                final String message;
+                final String[][] data;
+                if (unit.isPioneer()) {
+                    if (unitOnShip) {
+                        message = "tutorial.equipColonist.unload";
+                        data = new String[][] {
+                                {"%unit%", unit.getName()},
+                                {"%equipGeneral%", Messages.message("tutorial.equipColonist.general")},
+                                {"%outsideColony%", Messages.message("outsideColony")},
+                                {"%amount%", Integer.toString(unit.getNumberOfTools())},
+                        };
+                    } else {
+                        message = "tutorial.equipColonist.ready";
+                        data = new String[][] {
+                                {"%unit%", unit.getName()},
+                                {"%equipGeneral%", Messages.message("tutorial.equipColonist.general")},
+                                {"%colony%", colony.getName()},
+                                {"%amount%", Integer.toString(unit.getNumberOfTools())},
+                        };
+                    }
+                } else {
+                    if (unitOnShip) {
+                        message = "tutorial.equipColonist.ship";
+                    } else {
+                        message = "tutorial.equipColonist.normal";
+                    }
+                    data = new String[][] {
+                            {"%unit%", unit.getName()},
+                            {"%equipGeneral%", Messages.message("tutorial.equipColonist.general")},
+                            {"%colony%", colony.getName()},
+                            {"%amount%", Integer.toString(colony.getGoodsCount(Goods.TOOLS))},
+                            {"%outsideColony%", Messages.message("outsideColony")}
+                    };
+                }
+                player.addModelMessage(new ModelMessage(player, message, data, ModelMessage.TUTORIAL, unit));
+                freeColClient.getInGameController().nextModelMessage();
+            }
+        }
+        // END TUTORIAL
     }
 
     /**
