@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui;
 
 import java.awt.Color;
@@ -24,6 +43,7 @@ import net.sf.freecol.client.gui.panel.ImageProvider;
 import net.sf.freecol.common.FreeColException;
 import net.sf.freecol.common.model.Building;
 import net.sf.freecol.common.model.Colony;
+import net.sf.freecol.common.model.IndianSettlement;
 import net.sf.freecol.common.model.Settlement;
 import net.sf.freecol.common.model.Tension;
 import net.sf.freecol.common.model.Tile;
@@ -36,11 +56,8 @@ import net.sf.freecol.common.model.Unit;
 public final class ImageLibrary extends ImageProvider {
     private static final Logger logger = Logger.getLogger(ImageLibrary.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2007 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2998 $";
 
     public static final int UNIT_SELECT = 0, PLOWED = 4, TILE_TAKEN = 5, TILE_OWNED_BY_INDIANS = 6,
             LOST_CITY_RUMOUR = 7, DARKNESS = 8, MISC_COUNT = 10;
@@ -132,9 +149,9 @@ public final class ImageLibrary extends ImageProvider {
             COLONY_LARGE_FORT = 8, COLONY_UNDEAD = 9, COLONY_COUNT = 10,
 
             INDIAN_SETTLEMENT_CAMP = 0,
-            // INDIAN_SETTLEMENT_VILLAGE = 1,
-            // INDIAN_SETTLEMENT_AZTEC = 2,
-            // INDIAN_SETTLEMENT_INCA = 3,
+            INDIAN_SETTLEMENT_VILLAGE = 1,
+            INDIAN_SETTLEMENT_AZTEC = 2,
+            INDIAN_SETTLEMENT_INCA = 3,
 
             INDIAN_COUNT = 4;
 
@@ -1454,18 +1471,17 @@ public final class ImageLibrary extends ImageProvider {
             }
 
         } else { // IndianSettlement
-            return INDIAN_SETTLEMENT_CAMP;
-
-            /*
-             * TODO: Use when we have graphics: IndianSettlement
-             * indianSettlement = (IndianSettlement) settlement; if
-             * (indianSettlement.getKind() == IndianSettlement.CAMP) { return
-             * INDIAN_SETTLEMENT_CAMP; } else if (indianSettlement.getKind() ==
-             * IndianSettlement.VILLAGE) { return INDIAN_SETTLEMENT_VILLAGE; }
-             * else { //CITY if (indianSettlement.getTribe() ==
-             * IndianSettlement.AZTEC) return INDIAN_SETTLEMENT_AZTEC; else //
-             * INCA return INDIAN_SETTLEMENT_INCA; }
-             */
+            
+            IndianSettlement indianSettlement = (IndianSettlement) settlement;
+            if (indianSettlement.getKind() == IndianSettlement.CAMP) {
+                return INDIAN_SETTLEMENT_CAMP;
+            } else if (indianSettlement.getKind() == IndianSettlement.VILLAGE) { 
+                return INDIAN_SETTLEMENT_VILLAGE;
+            } else if (indianSettlement.getTribe() == IndianSettlement.AZTEC) {
+                return INDIAN_SETTLEMENT_AZTEC;
+            } else {
+                return INDIAN_SETTLEMENT_INCA;
+            }
         }
     }
 
