@@ -1,9 +1,26 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 
 package net.sf.freecol.client.gui;
 
-import java.awt.GraphicsEnvironment;
-import java.awt.Rectangle;
 import java.util.logging.Logger;
 
 import javax.swing.JComponent;
@@ -20,9 +37,6 @@ import net.sf.freecol.FreeCol;
 public final class WindowedFrame extends JFrame {
     private static final Logger logger = Logger.getLogger(WindowedFrame.class.getName());
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2986 $";
 
 
     private Canvas canvas;
