@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui.action;
 
 import java.awt.event.ActionEvent;
@@ -14,13 +33,10 @@ public class ExecuteGotoOrdersAction extends MapboardAction {
     @SuppressWarnings("unused")
     private static final Logger logger = Logger.getLogger(ExecuteGotoOrdersAction.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 1946 $";
 
-    public static final String ID = "executeGotoOrdersAction";
+    public static final String id = "executeGotoOrdersAction";
 
 
     /**
@@ -38,7 +54,7 @@ public class ExecuteGotoOrdersAction extends MapboardAction {
      * @return "waitAction"
      */
     public String getId() {
-        return ID;
+        return id;
     }
 
     /**
