@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui.panel;
 
 import java.awt.Color;
@@ -64,11 +83,8 @@ import cz.autel.dmi.HIGLayout;
  * in the colony, the buildings and much more.
  */
 public final class ColonyPanel extends FreeColPanel implements ActionListener {
-    public static final String COPYRIGHT = "Copyright (C) 2003-2007 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2998 $";
 
     private static Logger logger = Logger.getLogger(ColonyPanel.class.getName());
 
@@ -982,7 +998,7 @@ public final class ColonyPanel extends FreeColPanel implements ActionListener {
 
             public final int[] widths = { 162, 46, 46, 46, 90 };
 
-            public final int[] heights = { 60, 0 };
+            public final int[] heights = { 60, 0, 0 };
 
             public static final int labelColumn = 1;
             public static final int unitColumn = 2;
@@ -1024,10 +1040,12 @@ public final class ColonyPanel extends FreeColPanel implements ActionListener {
                     }
                     add(unitLabel, higConst.rc(1, unitColumn + index));
                     if (building.getType() == Building.SCHOOLHOUSE) {
+                        JLabel progress = new JLabel(unit.getTurnsOfTraining() + "/" + unit.getNeededTurnsOfTraining());
+                        add(progress, higConst.rc(2, unitColumn + index));
                         if (unit.getStudent() != null) {
                             UnitLabel studentLabel = new UnitLabel(unit.getStudent(), parent, true);
                             studentLabel.setIgnoreLocation(true);
-                            add(studentLabel, higConst.rc(2, unitColumn + index));
+                            add(studentLabel, higConst.rc(3, unitColumn + index));
                         }
                     }
                 }
@@ -1539,7 +1557,13 @@ public final class ColonyPanel extends FreeColPanel implements ActionListener {
 
             for (int x = 0; x < 3; x++) {
                 for (int y = 0; y < 3; y++) {
-                    ASingleTilePanel p = new ASingleTilePanel(getColony().getColonyTile(x, y), x, y);
+                	ColonyTile colonyTile = getColony().getColonyTile(x, y);
+                	
+                	//tile is outside the board, do not add it
+                	if(colonyTile == null){
+                		continue;
+                	}
+                    ASingleTilePanel p = new ASingleTilePanel(colonyTile, x, y);
                     add(p, new Integer(layer));
                     layer++;
                 }
@@ -1556,7 +1580,15 @@ public final class ColonyPanel extends FreeColPanel implements ActionListener {
             if (getColony() != null) {
                 for (int x = 0; x < 3; x++) {
                     for (int y = 0; y < 3; y++) {
-                        colonyTileGUI.displayColonyTile((Graphics2D) g, game.getMap(), getColony().getTile(x, y), ((2 - x) + y)
+                    	Tile colonyTile = getColony().getTile(x, y);
+                    	
+                    	// tile does not exist, colony at the edge of map
+                    	// do not draw it
+                    	if(colonyTile == null){
+                    		continue;
+                    	}
+                    	
+                        colonyTileGUI.displayColonyTile((Graphics2D) g, game.getMap(), colonyTile, ((2 - x) + y)
                                 * lib.getTerrainImageWidth(1) / 2, (x + y) * lib.getTerrainImageHeight(1) / 2,
                                 getColony());
 
