@@ -1,7 +1,27 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui.panel;
 
 import java.awt.event.MouseAdapter;
 import java.awt.event.MouseEvent;
+import java.awt.Color;
 import java.util.Iterator;
 
 import javax.swing.JComponent;
@@ -13,7 +33,6 @@ import net.sf.freecol.client.gui.ImageLibrary;
 import net.sf.freecol.client.gui.i18n.Messages;
 import net.sf.freecol.common.model.Building;
 import net.sf.freecol.common.model.Colony;
-import net.sf.freecol.common.model.ColonyTile;
 import net.sf.freecol.common.model.Goods;
 import net.sf.freecol.common.model.Unit;
 import net.sf.freecol.common.model.WorkLocation;
@@ -25,17 +44,14 @@ import net.sf.freecol.common.model.WorkLocation;
  */
 public final class DragListener extends MouseAdapter {
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2830 $";
 
-    private static final int[] goodsTypes = { Goods.FOOD, Goods.SUGAR, Goods.TOBACCO, Goods.COTTON, 
+    private static final int[] goodsTypes = { Goods.FOOD, Goods.SUGAR, Goods.TOBACCO, Goods.COTTON,
                                               Goods.FURS, Goods.LUMBER, Goods.ORE, Goods.SILVER };
 
     private static final int[] workTypes = { UnitLabel.WORKTYPE_FOOD, UnitLabel.WORKTYPE_SUGAR,
-                                             UnitLabel.WORKTYPE_TOBACCO, UnitLabel.WORKTYPE_COTTON, 
+                                             UnitLabel.WORKTYPE_TOBACCO, UnitLabel.WORKTYPE_COTTON,
                                              UnitLabel.WORKTYPE_FURS, UnitLabel.WORKTYPE_LUMBER,
                                              UnitLabel.WORKTYPE_ORE, UnitLabel.WORKTYPE_SILVER };
 
@@ -49,7 +65,7 @@ public final class DragListener extends MouseAdapter {
 
     /**
      * The constructor to use.
-     * 
+     *
      * @param parentPanel The layered pane that contains the components to which
      *            a DragListener might be attached.
      */
@@ -60,7 +76,7 @@ public final class DragListener extends MouseAdapter {
     /**
      * Gets called when the mouse was pressed on a Swing component that has this
      * object as a MouseListener.
-     * 
+     *
      * @param e The event that holds the information about the mouse click.
      */
     public void mousePressed(MouseEvent e) {
@@ -71,20 +87,24 @@ public final class DragListener extends MouseAdapter {
         if ((e.getButton() == MouseEvent.BUTTON3 || e.isPopupTrigger())) {
             // Popup mustn't be shown when panel is not editable
             if (!parentPanel.isEditable()) return;
-            
+
             if (comp instanceof UnitLabel) {
                 UnitLabel unitLabel = (UnitLabel) comp;
                 ImageLibrary imageLibrary = (ImageLibrary) unitLabel.getCanvas().getImageProvider();
                 Unit tempUnit = unitLabel.getUnit();
 
                 JPopupMenu menu = new JPopupMenu("Unit");
+                JMenuItem name = new JMenuItem(tempUnit.getName());
+                name.setEnabled(false);
+                menu.add(name);
+
                 JMenuItem menuItem;
                 boolean separatorNeeded = false;
 
-                if (tempUnit.getLocation().getTile() != null && 
+                if (tempUnit.getLocation().getTile() != null &&
                     tempUnit.getLocation().getTile().getSettlement() != null) {
                     Colony colony = (Colony) tempUnit.getLocation().getColony();
-                    
+
                     // Work in Field - automatically find the best location
                     for (int index = 0; index < goodsTypes.length; index++) {
                         int maxpotential = colony.getVacantColonyTileProductionFor(tempUnit, goodsTypes[index]);
@@ -97,7 +117,7 @@ public final class DragListener extends MouseAdapter {
                             menu.add(menuItem);
                         }
                     }
-                    
+
                     // Work at Building - show both max potential and realistic projection
                     Iterator<Building> buildingIterator = colony.getBuildingIterator();
                     while (buildingIterator.hasNext()) {
@@ -125,7 +145,7 @@ public final class DragListener extends MouseAdapter {
                             }
                         }
                     }
-                    
+
                     separatorNeeded = true;
                 }
 
@@ -142,7 +162,7 @@ public final class DragListener extends MouseAdapter {
                             teacher.getStudent() != tempUnit) {
                             menuItem = new JMenuItem(Messages.message("assignToTeacher"),
                                                      imageLibrary.getScaledUnitImageIcon(teacher.getType(), 0.5f));
-                            menuItem.setActionCommand("assign" + teacher.getID());
+                            menuItem.setActionCommand("assign" + teacher.getId());
                             menuItem.addActionListener(unitLabel);
                             menu.add(menuItem);
                             separatorNeeded = true;
@@ -287,7 +307,7 @@ public final class DragListener extends MouseAdapter {
                         menu.add(menuItem);
                         menu.addSeparator();
                     }
-                    
+
                 }
 
                 menuItem = new JMenuItem(Messages.message("menuBar.colopedia"));
@@ -295,6 +315,17 @@ public final class DragListener extends MouseAdapter {
                 menuItem.addActionListener(unitLabel);
                 menu.add(menuItem);
 
+                menu.addSeparator();
+                if (tempUnit.getExpertWorkType() >= 0) {
+                    JMenuItem teaching = new JMenuItem(Messages.message("menuBar.teacher") + ": " + tempUnit.getTurnsOfTraining() + "/" + tempUnit.getNeededTurnsOfTraining());
+                    teaching.setEnabled(false);
+                    menu.add(teaching);
+                }
+                int exprience = Math.min(tempUnit.getExperience(), 200);
+                JMenuItem experience = new JMenuItem(Messages.message("menuBar.experience") + ": " + exprience + "/200 (max. 4%");
+                experience.setEnabled(false);
+                menu.add(experience);
+
                 if (menu.getSubElements().length > 0) {
                     menu.show(comp, e.getX(), e.getY());
                 }
