@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui.panel;
 
 import java.awt.AWTEvent;
@@ -51,9 +70,6 @@ import cz.autel.dmi.HIGLayout;
 public class FreeColDialog extends FreeColPanel {
     private static final Logger logger = Logger.getLogger(FreeColDialog.class.getName());
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2007 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2645 $";
 
     public static final int SCOUT_INDIAN_SETTLEMENT_CANCEL = 0,
                             SCOUT_INDIAN_SETTLEMENT_SPEAK = 1,
@@ -128,7 +144,7 @@ public class FreeColDialog extends FreeColPanel {
                         MouseEvent me = (MouseEvent) event;
                         Component dc = SwingUtilities.getDeepestComponentAt(((ComponentEvent) event).getComponent(), me.getX(), me.getY());
                         // Block only MOUSE_CLICKED and MOUSE_PRESSED
-                        if ((event.getID() == MouseEvent.MOUSE_CLICKED || event.getID() == MouseEvent.MOUSE_PRESSED) &&
+                        if ((event.getId() == MouseEvent.MOUSE_CLICKED || event.getId() == MouseEvent.MOUSE_PRESSED) &&
                                 (dc == null || !SwingUtilities.isDescendingFrom(dc, this) || dc.getListeners(MouseListener.class).length == 0)) {
                             continue;
                         }
@@ -624,11 +640,12 @@ public class FreeColDialog extends FreeColPanel {
         // decide on some mnemonics for the actions
         char  okButtonMnemonic = '\0';
         char  cancelButtonMnemonic = '\0';
-        String  okLower = okText.toLowerCase();
-        String  cancelLower = cancelText.toLowerCase();
-        String  menuMnemonics = "gvorc";
-        for ( int ci = 0, nc = okLower.length();  ci < nc;  ci ++ ) {
-            char  ch = Character.toLowerCase( okLower.charAt(ci) );
+        String  okUpper = okText.toUpperCase();
+        String  cancelUpper = cancelText.toUpperCase();
+        // XXX: This should be factored out to remove the magic string
+        String  menuMnemonics = "GVORCD";
+        for ( int ci = 0, nc = okUpper.length();  ci < nc;  ci ++ ) {
+            char  ch = okUpper.charAt(ci);
 
             // if the character at "ci" in "okText" is not claimed by the menu..
             if ( -1 == menuMnemonics.indexOf(ch) ) {
@@ -637,13 +654,13 @@ public class FreeColDialog extends FreeColPanel {
                 break;
             }
         }
-        for ( int ci = 0, nc = cancelLower.length();  ci < nc;  ci ++ ) {
-            char  ch = Character.toLowerCase( cancelLower.charAt(ci) );
+        for ( int ci = 0, nc = cancelUpper.length();  ci < nc;  ci ++ ) {
+            char  ch = cancelUpper.charAt(ci);
 
             // if the character at "ci" in "cancelText" is not claimed by the
-            // menu nor by "okText"..
-            if ( -1 == menuMnemonics.indexOf(ch)  &&  -1 == okLower.indexOf(ch) ) {
-
+            // menu nor by okButton..
+            if ( -1 == menuMnemonics.indexOf(ch)  &&  ch != okButtonMnemonic ) {
+            
                 cancelButtonMnemonic = ch;
                 break;
             }
