@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui.panel;
 
 import java.awt.Color;
@@ -31,9 +50,6 @@ import net.sf.freecol.common.model.Tile;
  * clicking on it.
  */
 public final class MiniMap extends JPanel implements MouseInputListener {
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String REVISION = "$Revision: 2998 $";
 
     @SuppressWarnings("unused")
     private static final Logger logger = Logger.getLogger(MiniMap.class.getName());
@@ -108,8 +124,8 @@ public final class MiniMap extends JPanel implements MouseInputListener {
         }
 
         // Add buttons:
-        miniMapZoomOutButton = new UnitButton(freeColClient.getActionManager().getFreeColAction(MiniMapZoomOutAction.ID));
-        miniMapZoomInButton = new UnitButton(freeColClient.getActionManager().getFreeColAction(MiniMapZoomInAction.ID));
+        miniMapZoomOutButton = new UnitButton(freeColClient.getActionManager().getFreeColAction(MiniMapZoomOutAction.id));
+        miniMapZoomInButton = new UnitButton(freeColClient.getActionManager().getFreeColAction(MiniMapZoomInAction.id));
 
         miniMapZoomOutButton.setFocusable(false);
         miniMapZoomInButton.setFocusable(false);
