@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.client.gui.panel;
 
 import java.awt.Component;
@@ -43,11 +62,8 @@ import cz.autel.dmi.HIGLayout;
 public final class TradeRouteInputDialog extends FreeColDialog implements ActionListener {
     private static final Logger logger = Logger.getLogger(TradeRouteInputDialog.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2007 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2622 $";
 
     private static final int OK = 0, CANCEL = 1;
 
@@ -270,6 +286,15 @@ public final class TradeRouteInputDialog extends FreeColDialog implements Action
         ok.requestFocus();
     }
 
+    private boolean verifyNewTradeRoute(){
+    	// Verify that it has at least two stops
+    	if(listModel.getSize() < 2){
+    		 getCanvas().errorMessage("traderouteDialog.notEnoughStops");
+    		 return false;
+    	} 	
+    	return true;
+    }
+    
     /**
      * This function analyses an event and calls the right methods to take care
      * of the user's requests.
@@ -281,6 +306,10 @@ public final class TradeRouteInputDialog extends FreeColDialog implements Action
         try {
             switch (Integer.valueOf(command).intValue()) {
             case OK:
+            	// the
+            	if(! verifyNewTradeRoute())
+            		break;
+            	
                 getCanvas().remove(this);
                 originalRoute.setName(tradeRouteName.getText());
                 ArrayList<Stop> stops = new ArrayList<Stop>();
