@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.common.model;
 
 import java.util.ArrayList;
@@ -36,11 +55,8 @@ import org.w3c.dom.Element;
  */
 public final class Building extends FreeColGameObject implements WorkLocation, Ownable, Nameable {
     
-    public static final String COPYRIGHT = "Copyright (C) 2003-2006 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2838 $";
 
     /**
      * The maximum level.
@@ -483,7 +499,7 @@ public final class Building extends FreeColGameObject implements WorkLocation, O
         Unit student = unit.getStudent();
         if (getType() == SCHOOLHOUSE) {
             if (student == null) {
-                student = findStudent();
+                student = findStudent(unit.getExpertWorkType());
                 if (student != null) {
                     unit.setStudent(student);
                     student.setTeacher(unit);
@@ -682,12 +698,31 @@ public final class Building extends FreeColGameObject implements WorkLocation, O
         }
     }
 
-    private Unit findStudent() {
+    private Unit findStudent(int goodsType) {
         Unit student = null;
         int skill = Integer.MIN_VALUE;
+        // First check if there's a potential student in the appropriate building (works only for building-jobs)
+        if (goodsType > -1) {
+			Building someBuilding = getColony().getBuildingForProducing(goodsType);
+			if (someBuilding != null) {
+				List<Unit> potentialStudentList = someBuilding.getUnitList();
+	        	for (Unit potentialStudent : potentialStudentList) {
+	            	if (potentialStudent.canBeStudent() && potentialStudent.getTeacher() == null) {
+	                	// prefer students with higher skill levels
+	                	if (potentialStudent.getSkillLevel() > skill) {
+	                    	student = potentialStudent;
+	                    	skill = student.getSkillLevel();
+	                	}
+	            	}
+	        	}
+	            if (student != null) {
+	                return student;
+	            }
+			}
+        }
+        // Then check the entire colony's population.
         for (Unit potentialStudent : getColony().getUnitList()) {
-            if (potentialStudent.canBeStudent() &&
-                potentialStudent.getTeacher() == null) {
+            if (potentialStudent.canBeStudent() && potentialStudent.getTeacher() == null) {
                 // prefer students with higher skill levels
                 if (potentialStudent.getSkillLevel() > skill) {
                     student = potentialStudent;
@@ -705,7 +740,7 @@ public final class Building extends FreeColGameObject implements WorkLocation, O
         while (teachers.hasNext()) {
             Unit teacher = teachers.next();
             if (teacher.getStudent() == null) {
-                Unit student = findStudent();
+                Unit student = findStudent(teacher.getExpertWorkType());
                 if (student == null) {
                     addModelMessage(getColony(), "model.building.noStudent",
                                     new String[][] {
@@ -1244,8 +1279,8 @@ public final class Building extends FreeColGameObject implements WorkLocation, O
         out.writeStartElement(getXMLElementTagName());
 
         // Add attributes:
-        out.writeAttribute("ID", getID());
-        out.writeAttribute("colony", colony.getID());
+        out.writeAttribute("ID", getId());
+        out.writeAttribute("colony", colony.getId());
         out.writeAttribute("type", Integer.toString(type));
         out.writeAttribute("level", Integer.toString(level));
 
@@ -1267,7 +1302,7 @@ public final class Building extends FreeColGameObject implements WorkLocation, O
      */
     @Override
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         colony = (Colony) getGame().getFreeColGameObject(in.getAttributeValue(null, "colony"));
         if (colony == null) {
