@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.common.model;
 
@@ -22,9 +41,6 @@ import org.w3c.dom.Element;
 */
 public class ColonyTile extends FreeColGameObject implements WorkLocation, Ownable {
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2838 $";
 
     private static final Logger logger = Logger.getLogger(ColonyTile.class.getName());
 
@@ -274,7 +290,7 @@ public class ColonyTile extends FreeColGameObject implements WorkLocation, Ownab
     */
     public void add(Locatable locatable) {
         if (isColonyCenterTile() || unit != null) {
-            throw new IllegalStateException("Other unit present while adding a unit to ColonyTile:" + getID());
+            throw new IllegalStateException("Other unit present while adding a unit to ColonyTile:" + getId());
         }
 
         if (!canAdd(locatable)) {
@@ -577,9 +593,9 @@ public class ColonyTile extends FreeColGameObject implements WorkLocation, Ownab
         out.writeStartElement(getXMLElementTagName());
         
         // Add attributes:       
-        out.writeAttribute("ID", getID());
-        out.writeAttribute("colony", colony.getID());
-        out.writeAttribute("workTile", workTile.getID());
+        out.writeAttribute("ID", getId());
+        out.writeAttribute("colony", colony.getId());
+        out.writeAttribute("workTile", workTile.getId());
 
         if (unit != null) {
             unit.toXML(out, player, showAll, toSavedGame);
@@ -596,7 +612,7 @@ public class ColonyTile extends FreeColGameObject implements WorkLocation, Ownab
      *      during parsing.
      */
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         colony = (Colony) getGame().getFreeColGameObject(in.getAttributeValue(null, "colony"));
         if (colony == null) {
