@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.common.model;
 
 import java.util.Iterator;
@@ -16,19 +35,16 @@ import org.w3c.dom.Element;
 /**
  * Represents Europe in the game. Each <code>Player</code> has it's own
  * <code>Europe</code>.
- * 
+ * <p/>
  * <br>
  * <br>
- * 
+ * <p/>
  * Europe is the place where you can {@link #recruit} and {@link #train} new
  * units. You may also sell/buy goods.
  */
 public final class Europe extends FreeColGameObject implements Location,
         Ownable {
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String REVISION = "$Revision: 2488 $";
 
     private static final Logger logger = Logger.getLogger(Europe.class
             .getName());
@@ -39,7 +55,7 @@ public final class Europe extends FreeColGameObject implements Location,
      * can be used to communicate with the server/client. The array holds
      * exactly 3 elements and element 0 corresponds to recruit slot 1.
      */
-    private int[] recruitables = { -1, -1, -1 };
+    private int[] recruitables = {-1, -1, -1};
 
     private int artilleryPrice;
     private int recruitPrice;
@@ -54,12 +70,10 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Creates a new <code>Europe</code>.
-     * 
-     * @param game
-     *            The <code>Game</code> in which this object belong.
-     * @param owner
-     *            The <code>Player</code> that will be using this object of
-     *            <code>Europe</code>.
+     *
+     * @param game  The <code>Game</code> in which this object belong.
+     * @param owner The <code>Player</code> that will be using this object of
+     *              <code>Europe</code>.
      */
     public Europe(Game game, Player owner) {
         super(game);
@@ -67,9 +81,9 @@ public final class Europe extends FreeColGameObject implements Location,
 
         unitContainer = new UnitContainer(game, this);
 
-        setRecruitable(0, owner.generateRecruitable());
-        setRecruitable(1, owner.generateRecruitable());
-        setRecruitable(2, owner.generateRecruitable());
+        setRecruitable(0, owner.generateRecruitable("r1"));
+        setRecruitable(1, owner.generateRecruitable("r2"));
+        setRecruitable(2, owner.generateRecruitable("r3"));
 
         artilleryPrice = 500;
         recruitPrice = RECRUIT_PRICE_INITIAL;
@@ -77,13 +91,10 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Initializes this object from an XML-representation of this object.
-     * 
-     * @param game
-     *            The <code>Game</code> in which this object belong.
-     * @param in
-     *            The input stream containing the XML.
-     * @throws XMLStreamException
-     *             if an error occured during parsing.
+     *
+     * @param game The <code>Game</code> in which this object belong.
+     * @param in   The input stream containing the XML.
+     * @throws XMLStreamException if an error occured during parsing.
      */
     public Europe(Game game, XMLStreamReader in) throws XMLStreamException {
         super(game, in);
@@ -93,11 +104,9 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Initializes this object from an XML-representation of this object.
-     * 
-     * @param game
-     *            The <code>Game</code> in which this object belong.
-     * @param e
-     *            An XML-element that will be used to initialize this object.
+     *
+     * @param game The <code>Game</code> in which this object belong.
+     * @param e    An XML-element that will be used to initialize this object.
      */
     public Europe(Game game, Element e) {
         super(game, e);
@@ -110,11 +119,9 @@ public final class Europe extends FreeColGameObject implements Location,
      * should later be initialized by calling either
      * {@link #readFromXML(XMLStreamReader)} or
      * {@link #readFromXMLElement(Element)}.
-     * 
-     * @param game
-     *            The <code>Game</code> in which this object belong.
-     * @param id
-     *            The unique identifier for this object.
+     *
+     * @param game The <code>Game</code> in which this object belong.
+     * @param id   The unique identifier for this object.
      */
     public Europe(Game game, String id) {
         super(game, id);
@@ -122,15 +129,13 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the type of the recruitable in Europe at the given slot.
-     * 
-     * @param slot
-     *            The slot of the recruitable whose type needs to be returned.
-     *            Should be 0, 1 or 2. NOTE - used to be 1, 2 or 3 and was
-     *            called with 1-3 by some classes and 0-2 by others, the method
-     *            itself expected 0-2.
+     *
+     * @param slot The slot of the recruitable whose type needs to be returned.
+     *             Should be 0, 1 or 2. NOTE - used to be 1, 2 or 3 and was
+     *             called with 1-3 by some classes and 0-2 by others, the method
+     *             itself expected 0-2.
      * @return The type of the recruitable in Europe at the given slot.
-     * @exception IllegalArgumentException
-     *                if the given <code>slot</code> does not exist.
+     * @throws IllegalArgumentException if the given <code>slot</code> does not exist.
      */
     public int getRecruitable(int slot) {
         if ((slot >= 0) && (slot < 3)) {
@@ -142,14 +147,12 @@ public final class Europe extends FreeColGameObject implements Location,
     /**
      * Sets the type of the recruitable in Europe at the given slot to the given
      * type.
-     * 
-     * @param slot
-     *            The slot of the recruitable whose type needs to be set. Should
-     *            be 0, 1 or 2. NOTE - changed in order to match getRecruitable
-     *            above!
-     * @param type
-     *            The new type for the unit at the given slot in Europe. Should
-     *            be a valid unit type.
+     *
+     * @param slot The slot of the recruitable whose type needs to be set. Should
+     *             be 0, 1 or 2. NOTE - changed in order to match getRecruitable
+     *             above!
+     * @param type The new type for the unit at the given slot in Europe. Should
+     *             be a valid unit type.
      */
     public void setRecruitable(int slot, int type) {
         // Note - changed in order to match getRecruitable
@@ -163,18 +166,13 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Recruits a unit from Europe.
-     * 
-     * @param slot
-     *            The slot the recruited unit(type) came from. This is needed
-     *            for setting a new recruitable to this slot.
-     * @param unit
-     *            The recruited unit.
-     * @param newRecruitable
-     *            The recruitable that will fill the now empty slot.
-     * @exception NullPointerException
-     *                if <code>unit == null</code>.
-     * @exception IllegalStateException
-     *                if the player recruiting the unit cannot afford the price.
+     *
+     * @param slot           The slot the recruited unit(type) came from. This is needed
+     *                       for setting a new recruitable to this slot.
+     * @param unit           The recruited unit.
+     * @param newRecruitable The recruitable that will fill the now empty slot.
+     * @throws NullPointerException  if <code>unit == null</code>.
+     * @throws IllegalStateException if the player recruiting the unit cannot afford the price.
      */
     public void recruit(int slot, Unit unit, int newRecruitable) {
         if (unit == null) {
@@ -188,50 +186,44 @@ public final class Europe extends FreeColGameObject implements Location,
         unit.getOwner().modifyGold(-getRecruitPrice());
         incrementRecruitPrice();
         unit.setLocation(this);
+        unit.getOwner().reduceCrosses();
         unit.getOwner().updateCrossesRequired();
-        unit.getOwner().setCrosses(0);
 
         setRecruitable(slot, newRecruitable);
     }
 
     /**
      * Causes a unit to emigrate from Europe.
-     * 
-     * @param slot
-     *            The slot the emigrated unit(type) came from. This is needed
-     *            for setting a new recruitable to this slot.
-     * @param unit
-     *            The recruited unit.
-     * @param newRecruitable
-     *            The recruitable that will fill the now empty slot.
-     * @exception NullPointerException
-     *                If <code>unit == null</code>.
-     * @exception IllegalStateException
-     *                If there is not enough crosses to emigrate the
-     *                <code>Unit</code>.
+     *
+     * @param slot           The slot the emigrated unit(type) came from. This is needed
+     *                       for setting a new recruitable to this slot.
+     * @param unit           The recruited unit.
+     * @param newRecruitable The recruitable that will fill the now empty slot.
+     * @throws NullPointerException  If <code>unit == null</code>.
+     * @throws IllegalStateException If there is not enough crosses to emigrate the
+     *                               <code>Unit</code>.
      */
     public void emigrate(int slot, Unit unit, int newRecruitable) {
         if (unit == null) {
             throw new NullPointerException();
         }
 
-        if (!unit.getOwner().checkEmigrate()) {
+        Player player = unit.getOwner();
+        if (!player.checkEmigrate()) {
             throw new IllegalStateException(
                     "Not enough crosses to emigrate unit: "
-                            + unit.getOwner().getCrosses() + "/"
-                            + unit.getOwner().getCrossesRequired());
+                            + player.getCrosses() + "/"
+                            + player.getCrossesRequired());
         }
 
         unit.setLocation(this);
-        // TODO: shouldn't we subtract a certain amount of crosses instead of
-        // just removing all
-        // crosses? I'm not sure how this was done in the original.
-        unit.getOwner().updateCrossesRequired();
-        unit.getOwner().setCrosses(0);
 
-        if (!unit.getOwner().hasFather(FoundingFather.WILLIAM_BREWSTER)) {
-            addModelMessage(this, "model.europe.emigrate", new String[][] { {
-                    "%unit%", unit.getName() } }, ModelMessage.UNIT_ADDED, unit);
+        player.reduceCrosses();
+        player.updateCrossesRequired();
+
+        if (!player.hasFather(FoundingFather.WILLIAM_BREWSTER)) {
+            addModelMessage(this, "model.europe.emigrate", new String[][]{{
+                    "%unit%", unit.getName()}}, ModelMessage.UNIT_ADDED, unit);
         }
         // In case William Brewster is in the congress we don't need to show a
         // message to the
@@ -242,7 +234,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Returns <i>null</i>.
-     * 
+     *
      * @return <i>null</i>.
      */
     public Tile getTile() {
@@ -251,9 +243,8 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Adds a <code>Locatable</code> to this Location.
-     * 
-     * @param locatable
-     *            The <code>Locatable</code> to add to this Location.
+     *
+     * @param locatable The <code>Locatable</code> to add to this Location.
      */
     public void add(Locatable locatable) {
         if (!(locatable instanceof Unit)) {
@@ -264,9 +255,8 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Removes a <code>Locatable</code> from this Location.
-     * 
-     * @param locatable
-     *            The <code>Locatable</code> to remove from this Location.
+     *
+     * @param locatable The <code>Locatable</code> to remove from this Location.
      */
     public void remove(Locatable locatable) {
         if (locatable instanceof Unit) {
@@ -279,9 +269,8 @@ public final class Europe extends FreeColGameObject implements Location,
     /**
      * Checks if the specified <code>Locatable</code> is at this
      * <code>Location</code>.
-     * 
-     * @param locatable
-     *            The <code>Locatable</code> to test the presence of.
+     *
+     * @param locatable The <code>Locatable</code> to test the presence of.
      * @return The result.
      */
     public boolean contains(Locatable locatable) {
@@ -299,9 +288,8 @@ public final class Europe extends FreeColGameObject implements Location,
     /**
      * Checks wether or not the specified locatable may be added to this
      * <code>Location</code>.
-     * 
-     * @param locatable
-     *            The <code>Locatable</code> to test the addabillity of.
+     *
+     * @param locatable The <code>Locatable</code> to test the addabillity of.
      * @return <i>true</i>.
      */
     public boolean canAdd(Locatable locatable) {
@@ -310,7 +298,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the amount of Units at this Location.
-     * 
+     *
      * @return The amount of Units at this Location.
      */
     public int getUnitCount() {
@@ -321,7 +309,7 @@ public final class Europe extends FreeColGameObject implements Location,
      * Gets a <code>List</code> of every <code>Unit</code> directly located
      * in this <code>Europe</code>. This does not include <code>Unit</code>s
      * on ships.
-     * 
+     *
      * @return The <code>List</code>.
      */
     public List<Unit> getUnitList() {
@@ -332,7 +320,7 @@ public final class Europe extends FreeColGameObject implements Location,
      * Gets an <code>Iterator</code> of every <code>Unit</code> directly
      * located in this <code>Europe</code>. This does not include
      * <code>Unit</code>s on ships.
-     * 
+     *
      * @return The <code>Iterator</code>.
      */
     public Iterator<Unit> getUnitIterator() {
@@ -341,7 +329,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the first <code>Unit</code> in this <code>Europe</code>.
-     * 
+     *
      * @return The first <code>Unit</code> in this <code>Europe</code>.
      */
     public Unit getFirstUnit() {
@@ -350,7 +338,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the last <code>Unit</code> in this <code>Europe</code>.
-     * 
+     *
      * @return The last <code>Unit</code> in this <code>Europe</code>.
      */
     public Unit getLastUnit() {
@@ -359,13 +347,10 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Trains a unit in Europe.
-     * 
-     * @param unit
-     *            The trained unit.
-     * @exception NullPointerException
-     *                if <code>unit == null</code>.
-     * @exception IllegalStateException
-     *                if the player recruiting the unit cannot afford the price.
+     *
+     * @param unit The trained unit.
+     * @throws NullPointerException  if <code>unit == null</code>.
+     * @throws IllegalStateException if the player recruiting the unit cannot afford the price.
      */
     public void train(Unit unit) {
         if (unit == null) {
@@ -386,7 +371,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the current price for an artillery.
-     * 
+     *
      * @return The current price of the artillery in this <code>Europe</code>.
      */
     public int getArtilleryPrice() {
@@ -395,7 +380,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the current price for a recruit.
-     * 
+     *
      * @return The current price of the recruit in this <code>Europe</code>.
      */
     public int getRecruitPrice() {
@@ -418,12 +403,10 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Sets the owner of this <code>Ownable</code>.
-     * 
-     * @param p
-     *            The <code>Player</code> that should take ownership of this
-     *            {@link Ownable}.
-     * @exception UnsupportedOperationException
-     *                is always thrown by this method.
+     *
+     * @param p The <code>Player</code> that should take ownership of this
+     *          {@link Ownable}.
+     * @throws UnsupportedOperationException is always thrown by this method.
      */
     public void setOwner(Player p) {
         throw new UnsupportedOperationException();
@@ -439,10 +422,10 @@ public final class Europe extends FreeColGameObject implements Location,
                 unit.setHitpoints(unit.getHitpoints() + 1);
                 if (unit.getHitpoints() == Unit.getInitialHitpoints(unit.getType())) {
                     addModelMessage(this, "model.unit.shipRepaired",
-                                    new String[][] {
-                                        { "%unit%", unit.getName() },
-                                        { "%repairLocation%", getLocationName() } },
-                                    ModelMessage.DEFAULT, this);
+                            new String[][]{
+                                    {"%unit%", unit.getName()},
+                                    {"%repairLocation%", getLocationName()}},
+                            ModelMessage.DEFAULT, this);
                 }
             }
         }
@@ -450,7 +433,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Returns the name of this location.
-     * 
+     *
      * @return The name of this location.
      */
     public String getLocationName() {
@@ -459,7 +442,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Returns the name of the owner's home port.
-     * 
+     *
      * @return The name of this location.
      */
     public String getName() {
@@ -471,58 +454,53 @@ public final class Europe extends FreeColGameObject implements Location,
      */
     public String toString() {
         switch (getOwner().getNation()) {
-        case Player.DUTCH:
-            return Messages.message("model.nation.Dutch.Europe");
-        case Player.ENGLISH:
-            return Messages.message("model.nation.English.Europe");
-        case Player.FRENCH:
-            return Messages.message("model.nation.French.Europe");
-        case Player.SPANISH:
-            return Messages.message("model.nation.Spanish.Europe");
-        default:
-            return "Europe";
+            case Player.DUTCH:
+                return Messages.message("model.nation.Dutch.Europe");
+            case Player.ENGLISH:
+                return Messages.message("model.nation.English.Europe");
+            case Player.FRENCH:
+                return Messages.message("model.nation.French.Europe");
+            case Player.SPANISH:
+                return Messages.message("model.nation.Spanish.Europe");
+            default:
+                return "Europe";
         }
     }
 
     /**
      * This method writes an XML-representation of this object to the given
      * stream.
-     * 
+     * <p/>
      * <br>
      * <br>
-     * 
+     * <p/>
      * Only attributes visible to the given <code>Player</code> will be added
      * to that representation if <code>showAll</code> is set to
      * <code>false</code>.
-     * 
-     * @param out
-     *            The target stream.
-     * @param player
-     *            The <code>Player</code> this XML-representation should be
-     *            made for, or <code>null</code> if
-     *            <code>showAll == true</code>.
-     * @param showAll
-     *            Only attributes visible to <code>player</code> will be added
-     *            to the representation if <code>showAll</code> is set to
-     *            <i>false</i>.
-     * @param toSavedGame
-     *            If <code>true</code> then information that is only needed
-     *            when saving a game is added.
-     * @throws XMLStreamException
-     *             if there are any problems writing to the stream.
+     *
+     * @param out         The target stream.
+     * @param player      The <code>Player</code> this XML-representation should be
+     *                    made for, or <code>null</code> if
+     *                    <code>showAll == true</code>.
+     * @param showAll     Only attributes visible to <code>player</code> will be added
+     *                    to the representation if <code>showAll</code> is set to
+     *                    <i>false</i>.
+     * @param toSavedGame If <code>true</code> then information that is only needed
+     *                    when saving a game is added.
+     * @throws XMLStreamException if there are any problems writing to the stream.
      */
     protected void toXMLImpl(XMLStreamWriter out, Player player,
-            boolean showAll, boolean toSavedGame) throws XMLStreamException {
+                             boolean showAll, boolean toSavedGame) throws XMLStreamException {
         // Start element:
         out.writeStartElement(getXMLElementTagName());
 
-        out.writeAttribute("ID", getID());
+        out.writeAttribute("ID", getId());
         out.writeAttribute("recruit0", Integer.toString(recruitables[0]));
         out.writeAttribute("recruit1", Integer.toString(recruitables[1]));
         out.writeAttribute("recruit2", Integer.toString(recruitables[2]));
         out.writeAttribute("artilleryPrice", Integer.toString(artilleryPrice));
         out.writeAttribute("recruitPrice", Integer.toString(recruitPrice));
-        out.writeAttribute("owner", owner.getID());
+        out.writeAttribute("owner", owner.getId());
 
         unitContainer.toXML(out, player, showAll, toSavedGame);
 
@@ -531,15 +509,13 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Initialize this object from an XML-representation of this object.
-     * 
-     * @param in
-     *            The input stream with the XML.
-     * @throws XMLStreamException
-     *             if a problem was encountered during parsing.
+     *
+     * @param in The input stream with the XML.
+     * @throws XMLStreamException if a problem was encountered during parsing.
      */
     protected void readFromXMLImpl(XMLStreamReader in)
             throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         recruitables[0] = Integer.parseInt(in.getAttributeValue(null,
                 "recruit0"));
@@ -575,7 +551,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Gets the tag name of the root element representing this object.
-     * 
+     *
      * @return "europe".
      */
     public static String getXMLElementTagName() {
@@ -584,7 +560,7 @@ public final class Europe extends FreeColGameObject implements Location,
 
     /**
      * Europe does not belong to a colony.
-     * 
+     *
      * @return Always returns null.
      */
     public Colony getColony() {
