@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.common.model;
 
@@ -31,9 +50,6 @@ import org.xml.sax.SAXException;
 * The superclass of all game objects in FreeCol.
 */
 abstract public class FreeColGameObject {
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2406 $";
 
     private static final Logger logger = Logger.getLogger(FreeColGameObject.class.getName());
 
@@ -61,10 +77,10 @@ abstract public class FreeColGameObject {
             //game.setFreeColGameObject(id, this);            
             String nextID = getRealXMLElementTagName() + ":" + game.getNextID();
             if (nextID != null) {
-                setID(nextID);
+                setId(nextID);
             }
         } else if (this instanceof Game) {
-            setID("0");
+            setId("0");
         } else {
             logger.warning("Created 'FreeColGameObject' with 'game == null': " + this);
         }
@@ -125,7 +141,7 @@ abstract public class FreeColGameObject {
             logger.warning("Created 'FreeColGameObject' with 'game == null': " + this);
         }
 
-        setID(id);
+        setId(id);
         
         uninitialized = true;
     }
@@ -166,7 +182,7 @@ abstract public class FreeColGameObject {
     */
     public void dispose() {
         disposed = true;
-        getGame().removeFreeColGameObject(getID());
+        getGame().removeFreeColGameObject(getId());
     }
     
 
@@ -450,7 +466,7 @@ abstract public class FreeColGameObject {
     *
     * @return The unique ID of this object.
     */
-    public String getID() {
+    public String getId() {
         return id;
     }
 
@@ -481,11 +497,11 @@ abstract public class FreeColGameObject {
     *
     * @param newID the unique ID of this object,
     */
-    public void setID(String newID) {
+    public void setId(String newID) {
         if (game != null && !(this instanceof Game)) {
-            if (!newID.equals(getID())) {
-                if (getID() != null) {
-                    game.removeFreeColGameObject(getID());
+            if (!newID.equals(getId())) {
+                if (getId() != null) {
+                    game.removeFreeColGameObject(getId());
                 }
 
                 this.id = newID;
@@ -590,7 +606,7 @@ abstract public class FreeColGameObject {
     *         <i>false</i> otherwise.
     */
     public boolean hasID(String id) {
-        return getID().equals(id);
+        return getId().equals(id);
     }
 
 
@@ -602,7 +618,7 @@ abstract public class FreeColGameObject {
     */
     public boolean equals(FreeColGameObject o) {
         if (o != null) {
-            return getID().equals(o.getID());
+            return getId().equals(o.getId());
         } else {
             return false;
         }
@@ -619,7 +635,7 @@ abstract public class FreeColGameObject {
     }
         
     public int hashCode() {
-        return getID().hashCode();
+        return getId().hashCode();
     }
 
     
@@ -628,7 +644,7 @@ abstract public class FreeColGameObject {
     * @return The <code>String</code>
     */
     public String toString() {
-        return getClass().getName() + ": " + getID() + " (super's hash code: " + Integer.toHexString(super.hashCode()) + ")";
+        return getClass().getName() + ": " + getId() + " (super's hash code: " + Integer.toHexString(super.hashCode()) + ")";
     }
     
     /**
