@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.common.model;
 
 import java.io.File;
@@ -22,11 +41,8 @@ import javax.xml.stream.XMLStreamWriter;
  * perspective. In that case, some information might be missing from the model.
  */
 public class Game extends FreeColGameObject {
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2200 $";
 
     private static final Logger logger = Logger.getLogger(Game.class.getName());
 
@@ -40,6 +56,8 @@ public class Game extends FreeColGameObject {
     private Map map;
 
     private GameOptions gameOptions;
+    
+    private GameVariables gameVariables;
 
     /** The name of the player whose turn it is. */
     private Player currentPlayer = null;
@@ -91,6 +109,7 @@ public class Game extends FreeColGameObject {
         this.viewOwner = null;
 
         gameOptions = new GameOptions();
+        gameVariables = new GameVariables();
 
         currentPlayer = null;
         canGiveID = true;
@@ -412,9 +431,9 @@ public class Game extends FreeColGameObject {
     }
 
     /**
-     * Gets the <code>Map</code> that is beeing used in this game.
+     * Gets the <code>Map</code> that is being used in this game.
      * 
-     * @return The <code>Map</code> that is beeing used in this game or
+     * @return The <code>Map</code> that is being used in this game or
      *         <i>null</i> if no <code>Map</code> has been created.
      */
     public Map getMap() {
@@ -734,7 +753,7 @@ public class Game extends FreeColGameObject {
         while (iterator.hasNext()) {
             FreeColGameObject fgo = iterator.next();
             if (fgo.isUninitialized()) {
-                logger.warning("Uinitialized object: " + fgo.getID() + " (" + fgo.getClass() + ")");
+                logger.warning("Uinitialized object: " + fgo.getId() + " (" + fgo.getClass() + ")");
                 ok = false;
             }
         }
@@ -773,6 +792,14 @@ public class Game extends FreeColGameObject {
     public GameOptions getGameOptions() {
         return gameOptions;
     }
+    
+    /**
+     * Gets the <code>GameVariables</code> that is associated with this
+     * {@link Game}.
+     */
+    public GameVariables getGameVariables() {
+        return gameVariables;
+    }
 
     /**
      * Gets the amount of gold needed for inciting. This method should NEVER be
@@ -834,10 +861,10 @@ public class Game extends FreeColGameObject {
             throw new IllegalArgumentException("showAll must be set to true when toSavedGame is true.");
         }
 
-        out.writeAttribute("ID", getID());
+        out.writeAttribute("ID", getId());
         out.writeAttribute("turn", Integer.toString(getTurn().getNumber()));
         if (currentPlayer != null) {
-            out.writeAttribute("currentPlayer", currentPlayer.getID());
+            out.writeAttribute("currentPlayer", currentPlayer.getId());
         }
 
         if (toSavedGame) {
@@ -845,6 +872,9 @@ public class Game extends FreeColGameObject {
         }
 
         gameOptions.toXML(out);
+        if (gameVariables != null) {
+            gameVariables.toXML(out);
+        }
 
         Iterator<Player> playerIterator = getPlayerIterator();
         while (playerIterator.hasNext()) {
@@ -865,7 +895,7 @@ public class Game extends FreeColGameObject {
      * @param in The input stream with the XML.
      */
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         getTurn().setNumber(Integer.parseInt(in.getAttributeValue(null, "turn")));
 
@@ -894,6 +924,13 @@ public class Game extends FreeColGameObject {
                 } else {
                     gameOptions = new GameOptions(in);
                 }
+            } else if (in.getLocalName().equals(GameVariables.getXMLElementTagName())) {
+                // Gets the game variables:
+                if (gameVariables != null) {
+                    gameVariables.readFromXML(in);
+                } else {
+                    gameVariables = new GameVariables(in);
+                }
             } else if (in.getLocalName().equals(Player.getXMLElementTagName())) {
                 Player player = (Player) getFreeColGameObject(in.getAttributeValue(null, "ID"));
                 if (player != null) {
