@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.common.model;
 
@@ -36,9 +55,6 @@ import org.xml.sax.SAXException;
 */
 public class Goods implements Locatable, Ownable, Nameable {
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2821 $";
 
     private static Logger logger = Logger.getLogger(Goods.class.getName());
 
@@ -450,7 +466,7 @@ public class Goods implements Locatable, Ownable, Nameable {
         out.writeAttribute("amount", Integer.toString(amount));
 
         if (location != null) {
-            out.writeAttribute("location", location.getID());
+            out.writeAttribute("location", location.getId());
         } else {
             logger.warning("Creating an XML-element for a 'Goods' without a 'Location'.");
         }
