@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.common.model;
 
@@ -27,9 +46,6 @@ import org.w3c.dom.Element;
 public class IndianSettlement extends Settlement {
     private static final Logger logger = Logger.getLogger(IndianSettlement.class.getName());
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2707 $";
 
     public static final int INCA = 0;
     public static final int AZTEC = 1;
@@ -524,8 +540,45 @@ public class IndianSettlement extends Settlement {
         getTile().updatePlayerExploredTiles();
     }
 
-
-
+    /**
+     * Gets the response to an attempt to create a mission
+     * @return response
+     */
+    public String getResponseToMissionaryAttempt(int tension, String success) {
+    	String response = null;
+    	
+    	// Attempt Successful
+    	if(success.equals("true")){
+    		switch(tension){
+    			case Tension.HAPPY:
+    				response = "indianSettlement.mission.Happy";
+    				break;
+    			case Tension.CONTENT:
+    				response = "indianSettlement.mission.Content";
+    				break;
+    			case Tension.DISPLEASED:
+    				response = "indianSettlement.mission.Displeased";
+    				break;
+    			default:
+    				logger.warning("Unknown response for tension " + tension);
+    		}
+    				
+    	}
+    	else{
+    		switch(tension){
+    			case Tension.ANGRY:
+    				response = "indianSettlement.mission.Angry";
+    				break;	
+    			case Tension.HATEFUL:
+    				response = "indianSettlement.mission.Hateful";
+    				break;	
+    			default:
+    				logger.warning("Requesting reaction when no mission was established");
+    		}
+    	}
+    	return response;
+    }
+    
     public int[] getWantedGoods() {
         return wantedGoods;
     }
@@ -1016,7 +1069,7 @@ public class IndianSettlement extends Settlement {
         // Alcohol also contributes to create children. 
         if (goodsContainer.getGoodsCount(Goods.FOOD) + 4*goodsContainer.getGoodsCount(Goods.RUM) > 200+KEEP_RAW_MATERIAL ) {
             if (workers <= 6 + getKind()) { // up to a limit. Anyway cities produce more children than camps
-                Unit u = getGame().getModelController().createUnit(getID() + "newTurn200food", getTile(),
+                Unit u = getGame().getModelController().createUnit(getId() + "newTurn200food", getTile(),
                                                                    getOwner(), Unit.BRAVE);
                 consumeGoods(Goods.FOOD, 200);  // All food will be consumed, even if RUM helped
                 consumeGoods(Goods.RUM, 200/4);    // Also, some available RUM is consumed
@@ -1027,7 +1080,7 @@ public class IndianSettlement extends Settlement {
                                     new String[][] {{"%nation%", getOwner().getNationAsString()}},
                                     ModelMessage.UNIT_ADDED);
                  */
-                logger.info("New indian native created in " + getTile() + " with ID=" + u.getID());
+                logger.info("New indian native created in " + getTile() + " with ID=" + u.getId());
             }
         }
         // end Create Indian when enough food
@@ -1131,11 +1184,11 @@ public class IndianSettlement extends Settlement {
                     getUnitIterator().next().dispose();
                     convertProgress = 0;
 
-                    Unit u = getGame().getModelController().createUnit(getID() + "newTurn100missionary", targetTile, missionary.getOwner(), Unit.INDIAN_CONVERT);
+                    Unit u = getGame().getModelController().createUnit(getId() + "newTurn100missionary", targetTile, missionary.getOwner(), Unit.INDIAN_CONVERT);
                     addModelMessage(u, "model.colony.newConvert",
                                     new String[][] {{"%nation%", getOwner().getNationAsString()}},
                                     ModelMessage.UNIT_ADDED);
-                    logger.info("New convert created for " + missionary.getOwner().getName() + " with ID=" + u.getID());
+                    logger.info("New convert created for " + missionary.getOwner().getName() + " with ID=" + u.getId());
                 }
             }
         }
@@ -1227,9 +1280,9 @@ public class IndianSettlement extends Settlement {
             logger.warning("toSavedGame is true, but showAll is false");
         }
 
-        out.writeAttribute("ID", getID());
-        out.writeAttribute("tile", tile.getID());
-        out.writeAttribute("owner", owner.getID());
+        out.writeAttribute("ID", getId());
+        out.writeAttribute("tile", tile.getId());
+        out.writeAttribute("owner", owner.getId());
         out.writeAttribute("tribe", Integer.toString(tribe));
         out.writeAttribute("kind", Integer.toString(kind));
         out.writeAttribute("lastTribute", Integer.toString(lastTribute));
@@ -1238,7 +1291,7 @@ public class IndianSettlement extends Settlement {
         if (getGame().isClientTrusted() || showAll || player == getOwner()) {
             String ownedUnitsString = "";
             for (int i=0; i<ownedUnits.size(); i++) {
-                ownedUnitsString += ownedUnits.get(i).getID();
+                ownedUnitsString += ownedUnits.get(i).getId();
                 if (i != ownedUnits.size() - 1) {
                     ownedUnitsString += ", ";
                 }
@@ -1270,11 +1323,11 @@ public class IndianSettlement extends Settlement {
             goodsContainer.toXML(out, player, showAll, toSavedGame);
         } else {
             UnitContainer emptyUnitContainer = new UnitContainer(getGame(), this);
-            emptyUnitContainer.setFakeID(unitContainer.getID());
+            emptyUnitContainer.setFakeID(unitContainer.getId());
             emptyUnitContainer.toXML(out, player, showAll, toSavedGame);
 
             GoodsContainer emptyGoodsContainer = new GoodsContainer(getGame(), this);
-            emptyGoodsContainer.setFakeID(goodsContainer.getID());
+            emptyGoodsContainer.setFakeID(goodsContainer.getId());
             emptyGoodsContainer.toXML(out, player, showAll, toSavedGame);
         }
 
@@ -1289,7 +1342,7 @@ public class IndianSettlement extends Settlement {
      */
     @Override
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         tile = (Tile) getGame().getFreeColGameObject(in.getAttributeValue(null, "tile"));
         if (tile == null) {
@@ -1325,7 +1378,7 @@ public class IndianSettlement extends Settlement {
         wantedGoods[1] = getAttribute(in, "wantedGoods1", UNKNOWN);
         wantedGoods[2] = getAttribute(in, "wantedGoods2", UNKNOWN);
 
-        isVisited = getAttribute(in, "hasBeenVisisted", false);
+        isVisited = getAttribute(in, "hasBeenVisited", false);
         convertProgress = getAttribute(in, "convertProgress", UNKNOWN);
         lastTribute = getAttribute(in, "lastTribute", 0);
         learnableSkill = getAttribute(in, "learnableSkill", UNKNOWN);
