@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.common.model;
 
 import java.util.Comparator;
@@ -22,9 +41,6 @@ import net.sf.freecol.common.PseudoRandom;
  */
 public class Map extends FreeColGameObject {
     
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String REVISION = "$Revision: 2532 $";
 
     private static final Logger logger = Logger.getLogger(Map.class.getName());
 
@@ -370,7 +386,7 @@ public class Map extends FreeColGameObject {
                 });
         final HashMap<String, PathNode> closedList = new HashMap<String, PathNode>();
 
-        openList.put(firstNode.getTile().getID(), firstNode);
+        openList.put(firstNode.getTile().getId(), firstNode);
         openListQueue.offer(firstNode);
 
         while (openList.size() > 0) {
@@ -456,23 +472,23 @@ public class Map extends FreeColGameObject {
                         + getDistance(newTile.getPosition(), end.getPosition());
 
                 // Finding the node on the open list:
-                PathNode successor = openList.get(newTile.getID());
+                PathNode successor = openList.get(newTile.getId());
 
                 if (successor != null) {
                     if (successor.getF() <= f) {
                         continue;
                     } else {
-                        openList.remove(successor.getTile().getID());
+                        openList.remove(successor.getTile().getId());
                         openListQueue.remove(successor);
                     }
                 } else {
                     // Finding the node on the closed list.
-                    successor = closedList.get(newTile.getID());
+                    successor = closedList.get(newTile.getId());
                     if (successor != null) {
                         if (successor.getF() <= f) {
                             continue;
                         } else {
-                            closedList.remove(newTile.getID());
+                            closedList.remove(newTile.getId());
                         }
                     }
                 }
@@ -483,14 +499,14 @@ public class Map extends FreeColGameObject {
                 successor.setOnCarrier(onCarrier);
 
                 // Adding the new node to the open list:
-                openList.put(successor.getTile().getID(), successor);
+                openList.put(successor.getTile().getId(), successor);
                 openListQueue.offer(successor);
             }
 
-            closedList.put(currentNode.getTile().getID(), currentNode);
+            closedList.put(currentNode.getTile().getId(), currentNode);
 
             // Removing the current node from the open list:
-            openList.remove(currentNode.getTile().getID());
+            openList.remove(currentNode.getTile().getId());
             openListQueue.remove(currentNode);
         }
 
@@ -704,14 +720,14 @@ public class Map extends FreeColGameObject {
                 });
         final HashMap<String, PathNode> closedList = new HashMap<String, PathNode>();
 
-        openList.put(startTile.getID(), firstNode);
+        openList.put(startTile.getId(), firstNode);
         openListQueue.offer(firstNode);
 
         while (openList.size() > 0) {
             // Choosing the node with the lowest cost:
             PathNode currentNode = openListQueue.poll();
-            openList.remove(currentNode.getTile().getID());
-            closedList.put(currentNode.getTile().getID(), currentNode);
+            openList.remove(currentNode.getTile().getId());
+            closedList.put(currentNode.getTile().getId(), currentNode);
 
             // Reached the end
             if (currentNode.getTurns() > maxTurns) {
@@ -784,7 +800,7 @@ public class Map extends FreeColGameObject {
                 }
 
                 // Finding the node on the open list:
-                PathNode successor = closedList.get(newTile.getID());
+                PathNode successor = closedList.get(newTile.getId());
                 if (successor != null) {
                     if (successor.getCost() <= cost) {
                         continue;
@@ -792,12 +808,12 @@ public class Map extends FreeColGameObject {
                         logger.warning("This should not happen. :-(");
                     }
                 } else {
-                    successor = openList.get(newTile.getID());
+                    successor = openList.get(newTile.getId());
                     if (successor != null) {
                         if (successor.getCost() <= cost) {
                             continue;
                         } else {
-                            openList.remove(successor.getTile().getID());
+                            openList.remove(successor.getTile().getId());
                             openListQueue.remove(successor);
                         }
                     }
@@ -805,7 +821,7 @@ public class Map extends FreeColGameObject {
                             movesLeft, turns);
                     successor.previous = currentNode;
                     successor.setOnCarrier(onCarrier);
-                    openList.put(successor.getTile().getID(), successor);
+                    openList.put(successor.getTile().getId(), successor);
                     openListQueue.offer(successor);
                 }
             }
@@ -1790,7 +1806,7 @@ public class Map extends FreeColGameObject {
         // Start element:
         out.writeStartElement(getXMLElementTagName());
 
-        out.writeAttribute("ID", getID());
+        out.writeAttribute("ID", getId());
         out.writeAttribute("width", Integer.toString(getWidth()));
         out.writeAttribute("height", Integer.toString(getHeight()));
 
@@ -1802,7 +1818,7 @@ public class Map extends FreeColGameObject {
                 tile.toXML(out, player, showAll, toSavedGame);
             } else {
                 Tile hiddenTile = new Tile(getGame(), tile.getX(), tile.getY());
-                hiddenTile.setFakeID(tile.getID());
+                hiddenTile.setFakeID(tile.getId());
                 hiddenTile.toXML(out, player, showAll, toSavedGame);
             }
         }
@@ -1819,7 +1835,7 @@ public class Map extends FreeColGameObject {
     @Override
     protected void readFromXMLImpl(XMLStreamReader in)
             throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         if (columns == null) {
             int width = Integer.parseInt(in.getAttributeValue(null, "width"));
