@@ -1,7 +1,27 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.common.model;
 
 import java.util.ArrayList;
+
 import javax.xml.stream.XMLStreamConstants;
 import javax.xml.stream.XMLStreamException;
 import javax.xml.stream.XMLStreamReader;
@@ -16,9 +36,6 @@ import org.w3c.dom.Element;
  */
 public final class Market extends FreeColGameObject implements Ownable {
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2817 $";
 
     private Player owner;
     
@@ -488,8 +505,8 @@ public final class Market extends FreeColGameObject implements Ownable {
         // Start element:
         out.writeStartElement(getXMLElementTagName());
 
-        out.writeAttribute("ID", getID());
-        out.writeAttribute("owner", owner.getID());
+        out.writeAttribute("ID", getId());
+        out.writeAttribute("owner", owner.getId());
         toArrayElement("initialPrices", initialPrices, out);
         
         for (int i=0; i<dataForGoodType.length;i++) {
@@ -504,7 +521,7 @@ public final class Market extends FreeColGameObject implements Ownable {
      * @param in The input stream with the XML.
      */
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
         
         owner = (Player) getGame().getFreeColGameObject(in.getAttributeValue(null, "owner"));
         if (owner == null) {
@@ -622,7 +639,7 @@ public final class Market extends FreeColGameObject implements Ownable {
             // Start element:
             out.writeStartElement(getXMLElementTagName());
 
-            out.writeAttribute("ID", getID());
+            out.writeAttribute("ID", getId());
             out.writeAttribute("amount", Integer.toString(amountInMarket));
 
             out.writeEndElement();
@@ -633,7 +650,7 @@ public final class Market extends FreeColGameObject implements Ownable {
          * @param in The input stream with the XML.
          */
         protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-            setID(in.getAttributeValue(null, "ID"));
+            setId(in.getAttributeValue(null, "ID"));
 
             amountInMarket = Integer.parseInt(in.getAttributeValue(null, "amount"));
             
