@@ -1,6 +1,27 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.common.model;
 
+import java.util.ArrayList;
+
 import javax.xml.stream.XMLStreamException;
 import javax.xml.stream.XMLStreamReader;
 import javax.xml.stream.XMLStreamWriter;
@@ -17,9 +38,6 @@ import org.w3c.dom.Element;
  */
 public final class Monarch extends FreeColGameObject {
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2006 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2219 $";
 
     /** The name of this monarch. */
     private String name;
@@ -35,9 +53,10 @@ public final class Monarch extends FreeColGameObject {
         SUPPORT_SEA = 4,
         SUPPORT_LAND = 5,
         OFFER_MERCENARIES = 6,
-        NUMBER_OF_ACTIONS = 7,
-        WAIVE_TAX = 8,
-        ADD_UNITS = 9;
+        LOWER_TAX = 7,
+        NUMBER_OF_ACTIONS = 8,
+        WAIVE_TAX = 9,
+        ADD_UNITS = 10;
 
     /** Constants describing the REF. */
     public static final int INFANTRY = 0,
@@ -54,6 +73,12 @@ public final class Monarch extends FreeColGameObject {
      */
     private static final int MAXIMUM_TAX_RATE = 95;
 
+    /**
+     * The minimun tax rate (given in percentage) from where it
+     *can be lowered 
+     */
+    private static final int MINIMUM_TAX_RATE = 20;
+    
     /** The number of units in the REF. */
     private int[] ref = new int[NUMBER_OF_TYPES];       
 
@@ -190,7 +215,7 @@ public final class Monarch extends FreeColGameObject {
         probability[NO_ACTION] = Math.max(200 - turn, 100);
 
         if (player.getTax() < MAXIMUM_TAX_RATE) {
-            probability[RAISE_TAX] = 10 + dx;
+            probability[RAISE_TAX] = 5 + dx;
         }
         
         probability[ADD_TO_REF] = 10 + dx;
@@ -212,6 +237,10 @@ public final class Monarch extends FreeColGameObject {
             }
         }
         
+        if (player.getTax() > MINIMUM_TAX_RATE) {
+            probability[LOWER_TAX] = (int) Math.ceil(probability[RAISE_TAX]/2);
+        }
+        
         int accumulator = 0;
         for (int k = 0; k < NUMBER_OF_ACTIONS; k++ ) {
             accumulator += probability[k];
@@ -244,13 +273,31 @@ public final class Monarch extends FreeColGameObject {
      *
      * @return The increased tax.
      */
-    public int getNewTax() {
+    public int getNewTax(int taxChange) {
         int turn = getGame().getTurn().getNumber();
-        int adjustment = (6 - player.getDifficulty()) * 10; // 20-60
-        // later in the game, the taxes will increase by more
-        int increase = getGame().getModelController().getPseudoRandom().nextInt(5 + turn/adjustment) + 1;
-        int newTax = player.getTax() + increase;
-        return Math.min(newTax, MAXIMUM_TAX_RATE);            
+        
+        int newTax = 0;
+        int adjustment = 100;
+        
+        switch(taxChange){
+        	case Monarch.RAISE_TAX:
+        		adjustment = (6 - player.getDifficulty()) * 10; // 20-60
+        		// later in the game, the taxes will increase by more
+        		int increase = getGame().getModelController().getPseudoRandom().nextInt(5 + turn/adjustment) + 1;
+        		newTax = player.getTax() + increase;
+        		newTax = Math.min(newTax, MAXIMUM_TAX_RATE);
+        		break;
+        	case Monarch.LOWER_TAX:
+        		adjustment = 10 - player.getDifficulty(); // 5-10
+        		int decrease = getGame().getModelController().getPseudoRandom().nextInt(adjustment) + 1;
+        		newTax = player.getTax() - decrease;
+        		newTax = Math.max(newTax, MINIMUM_TAX_RATE);
+        		break;
+        	default:
+        		throw new IllegalStateException("Unknown tax change");
+        }
+        
+        return newTax;
     }
 
 
@@ -413,22 +460,26 @@ public final class Monarch extends FreeColGameObject {
      * @return The enemy nation.
      */
     public int declareWar() {
-        int offset = getGame().getModelController().getPseudoRandom().nextInt(Player.NUMBER_OF_NATIONS);
+        ArrayList<Integer> europeanPlayers = new ArrayList<Integer>();
         for (int i = 0; i < Player.NUMBER_OF_NATIONS; i++) {
-            int nation = (i + offset) % Player.NUMBER_OF_NATIONS;
-            if (nation == player.getNation()) {
+            if (i == player.getNation()) {
                 continue;
-            } else if (!player.hasContacted(nation)) {
+            } else if (!player.hasContacted(i)) {
                 continue;
             } else if (!getGame().getPlayer(i).isEuropean() || getGame().getPlayer(i).isREF()) {
                 continue;
             }
-            int stance = player.getStance(nation);
+            int stance = player.getStance(i);
             if (stance == Player.PEACE || stance == Player.CEASE_FIRE) {
-                player.setStance(getGame().getPlayer(nation), Player.WAR);
-                return nation;
+                europeanPlayers.add(i);
             }
         }
+        if (europeanPlayers.size() > 0) {
+            int random = getGame().getModelController().getPseudoRandom().nextInt(europeanPlayers.size());
+            int enemy = europeanPlayers.get(random);
+            player.setStance(getGame().getPlayer(enemy), Player.WAR);
+            return enemy;
+        }
         return Player.NO_NATION;
     }
 
@@ -490,8 +541,8 @@ public final class Monarch extends FreeColGameObject {
         // Start element:
         out.writeStartElement(getXMLElementTagName());
 
-        out.writeAttribute("ID", getID());
-        out.writeAttribute("player", this.player.getID());
+        out.writeAttribute("ID", getId());
+        out.writeAttribute("player", this.player.getId());
         out.writeAttribute("name", name);
         out.writeAttribute("supportSea", String.valueOf(supportSea));
         toArrayElement("ref", ref, out);
@@ -504,7 +555,7 @@ public final class Monarch extends FreeColGameObject {
      * @param in The input stream with the XML.
      */
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
         
         player = (Player) getGame().getFreeColGameObject(in.getAttributeValue(null, "player"));
         if (player == null) {
