@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.common.model;
 
 import java.util.Iterator;
@@ -25,11 +44,8 @@ import org.w3c.dom.Element;
 public final class Tile extends FreeColGameObject implements Location, Nameable {
     private static final Logger logger = Logger.getLogger(Tile.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 3025 $";
 
     // The type of a Tile can be one of the following.
     public static final int UNEXPLORED = 0, PLAINS = 1, GRASSLANDS = 2, PRAIRIE = 3, SAVANNAH = 4, MARSH = 5,
@@ -399,6 +415,53 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
                 // TODO: Uncomment when wagon train code has been written:
                 // value -= 20;
                 value = 0;
+            } else {
+                // TODO: Remove when wagon train code has been written. START
+                final GoalDecider gd = new GoalDecider() {
+                    private PathNode goal = null;
+
+                    public PathNode getGoal() {
+                        return goal;
+                    }
+
+                    public boolean hasSubGoals() {
+                        return false;
+                    }
+
+                    public boolean check(Unit u, PathNode pathNode) {
+                        Map map = getGame().getMap();
+
+                        if (pathNode.getTile().getType() == Tile.HIGH_SEAS) {
+                            goal = pathNode;
+                            return true;
+                        }
+                        if (map.isAdjacentToMapEdge(pathNode.getTile())) {
+                            goal = pathNode;
+                            return true;
+                        }
+                        return false;
+                    }
+                };
+                final CostDecider cd = new CostDecider() {
+                    public int getCost(Unit unit, Tile oldTile, Tile newTile, int movesLeft, int turns) {
+                        if (newTile.isLand()) {
+                            return ILLEGAL_MOVE;
+                        } else {
+                            return 1;
+                        }
+                    }
+                    public int getMovesLeft() {
+                        return 0;
+                    }
+                    public boolean isNewTurn() {
+                        return false;
+                    }
+                };
+                final PathNode n = getMap().search(this, gd, cd, Integer.MAX_VALUE);
+                if (n == null) {
+                    value = 0;
+                }
+                // END-TODO
             }
 
             return Math.max(0, value);
@@ -1504,7 +1567,7 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
             }
         }
 
-        out.writeAttribute("ID", getID());
+        out.writeAttribute("ID", getId());
         out.writeAttribute("x", Integer.toString(x));
         out.writeAttribute("y", Integer.toString(y));
         out.writeAttribute("type", Integer.toString(type));
@@ -1540,7 +1603,7 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
         }
 
         if ((getGame().isClientTrusted() || showAll || player.canSee(this)) && (owner != null)) {
-            out.writeAttribute("owner", owner.getID());
+            out.writeAttribute("owner", owner.getId());
         }
 
         // if ((settlement != null) && (showAll || player.canSee(this))) {
@@ -1552,22 +1615,22 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
                     if (!player.canSee(getTile())) {
                         if (pet.getColonyUnitCount() != 0) {
                             out.writeStartElement(Colony.getXMLElementTagName());
-                            out.writeAttribute("ID", getColony().getID());
+                            out.writeAttribute("ID", getColony().getId());
                             out.writeAttribute("name", getColony().getName());
-                            out.writeAttribute("owner", getColony().getOwner().getID());
-                            out.writeAttribute("tile", getID());
+                            out.writeAttribute("owner", getColony().getOwner().getId());
+                            out.writeAttribute("tile", getId());
                             out.writeAttribute("unitCount", Integer.toString(pet.getColonyUnitCount()));
 
                             Building b = getColony().getBuilding(Building.STOCKADE);
                             out.writeStartElement(Building.getXMLElementTagName());
-                            out.writeAttribute("ID", b.getID());
+                            out.writeAttribute("ID", b.getId());
                             out.writeAttribute("level", Integer.toString(pet.getColonyStockadeLevel()));
-                            out.writeAttribute("colony", getColony().getID());
+                            out.writeAttribute("colony", getColony().getId());
                             out.writeAttribute("type", Integer.toString(Building.STOCKADE));
                             out.writeEndElement();
 
                             GoodsContainer emptyGoodsContainer = new GoodsContainer(getGame(), getColony());
-                            emptyGoodsContainer.setFakeID(getColony().getGoodsContainer().getID());
+                            emptyGoodsContainer.setFakeID(getColony().getGoodsContainer().getId());
                             emptyGoodsContainer.toXML(out, player, showAll, toSavedGame);
 
                             out.writeEndElement();
@@ -1579,9 +1642,9 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
                     final IndianSettlement is = (IndianSettlement) getSettlement();
 
                     out.writeStartElement(IndianSettlement.getXMLElementTagName());
-                    out.writeAttribute("ID", getSettlement().getID());
-                    out.writeAttribute("tile", getID());
-                    out.writeAttribute("owner", getSettlement().getOwner().getID());
+                    out.writeAttribute("ID", getSettlement().getId());
+                    out.writeAttribute("tile", getId());
+                    out.writeAttribute("owner", getSettlement().getOwner().getId());
                     out.writeAttribute("tribe", Integer.toString(is.getTribe()));
                     out.writeAttribute("kind", Integer.toString(is.getKind()));
                     out.writeAttribute("isCapital", Boolean.toString(is.isCapital()));
@@ -1603,11 +1666,11 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
                     }
 
                     UnitContainer emptyUnitContainer = new UnitContainer(getGame(), getSettlement());
-                    emptyUnitContainer.setFakeID(is.getUnitContainer().getID());
+                    emptyUnitContainer.setFakeID(is.getUnitContainer().getId());
                     emptyUnitContainer.toXML(out, player, showAll, toSavedGame);
 
                     GoodsContainer emptyGoodsContainer = new GoodsContainer(getGame(), is);
-                    emptyGoodsContainer.setFakeID(is.getGoodsContainer().getID());
+                    emptyGoodsContainer.setFakeID(is.getGoodsContainer().getId());
                     emptyGoodsContainer.toXML(out, player, showAll, toSavedGame);
 
                     out.writeEndElement();
@@ -1625,7 +1688,7 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
             unitContainer.toXML(out, player, showAll, toSavedGame);
         } else {
             UnitContainer emptyUnitContainer = new UnitContainer(getGame(), this);
-            emptyUnitContainer.setFakeID(unitContainer.getID());
+            emptyUnitContainer.setFakeID(unitContainer.getId());
             emptyUnitContainer.toXML(out, player, showAll, toSavedGame);
         }
 
@@ -1646,7 +1709,7 @@ public final class Tile extends FreeColGameObject implements Location, Nameable
      * @param in The input stream with the XML.
      */
     protected void readFromXMLImpl(XMLStreamReader in) throws XMLStreamException {
-        setID(in.getAttributeValue(null, "ID"));
+        setId(in.getAttributeValue(null, "ID"));
 
         x = Integer.parseInt(in.getAttributeValue(null, "x"));
         y = Integer.parseInt(in.getAttributeValue(null, "y"));
