@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.server.ai;
 
 import java.io.IOException;
@@ -36,11 +55,8 @@ import org.w3c.dom.Element;
 public class AIColony extends AIObject {
     private static final Logger logger = Logger.getLogger(AIColony.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2659 $";
 
     /**
      * The FreeColGameObject this AIObject contains AI-information for.
@@ -63,10 +79,10 @@ public class AIColony extends AIObject {
      * @param colony The colony to make an {@link AIObject} for.
      */
     public AIColony(AIMain aiMain, Colony colony) {
-        super(aiMain, colony.getID());
+        super(aiMain, colony.getId());
 
         this.colony = colony;
-        colonyPlan = new ColonyPlan(aiMain, colony);
+        colonyPlan = new ColonyPlan(aiMain, colony);        
     }
 
     /**
@@ -133,6 +149,51 @@ public class AIColony extends AIObject {
         }
         super.dispose();
     }
+    
+    /**
+     * Updates custom house export settings.
+     */
+    private void updateCustomHouse() {
+        final int CAPACITY = colony.getWarehouseCapacity();
+        int[] exportLevels = new int[] {
+                 CAPACITY, // FOOD
+                        0, // SUGAR
+                        0, // TOBACCO
+                        0, // COTTON
+                        0, // FURS
+                 CAPACITY, // LUMBER
+                        0, // ORE
+                        0, // SILVER
+            CAPACITY - 20, // HORSES
+                        0, // RUM
+                        0, // CIGARS
+                        0, // CLOTH
+                        0, // COATS
+                        0, // TRADE_GOODS
+            Math.min(CAPACITY, 250), // TOOLS
+            CAPACITY - 50, // MUSKETS
+        };
+        boolean[] exports = new boolean[] {
+            false, //FOOD
+             true, // SUGAR
+             true, // TOBACCO
+             true, // COTTON
+             true, // FURS
+            false, // LUMBER
+             true, // ORE
+             true, // SILVER
+             true, // HORSES
+             true, // RUM
+             true, // CIGARS
+             true, // CLOTH
+             true, // COATS
+             true, // TRADE_GOODS
+             true, // TOOLS
+             true, // MUSKETS    
+        };
+        colony.setExports(exports);
+        colony.setExportLevel(exportLevels);
+    }
 
     /**
      * Returns an <code>Iterator</code> of the goods to be shipped from this
@@ -555,6 +616,13 @@ public class AIColony extends AIObject {
         ArrayList<AIGoods> newAIGoods = new ArrayList<AIGoods>();
 
         // TODO: Do not sell raw material we are lacking.
+        
+        updateCustomHouse();
+        if (colony.getBuilding(Building.CUSTOM_HOUSE).isBuilt()) {
+            // No need to export.
+            aiGoods.clear();
+            return;
+        }
 
         for (int goodsType = 0; goodsType < Goods.NUMBER_OF_TYPES; goodsType++) {
             // Never export food and lumber
@@ -626,7 +694,7 @@ public class AIColony extends AIObject {
                     } else if (ag.getGoods() == null) {
                         logger.warning("aiGoods.getGoods() == null");
                         if (ag.isUninitialized()) {
-                            logger.warning("AIGoods uninitialized: " + ag.getID());
+                            logger.warning("AIGoods uninitialized: " + ag.getId());
                         }
                     }
                     if (ag != null && ag.getGoods() != null && ag.getGoods().getType() == goodsType
@@ -1123,7 +1191,7 @@ public class AIColony extends AIObject {
 
             if (hammersNew > colony.getHammers() || hammersNew > hammersOld || !isOldValid) {
                 Element setCurrentlyBuildingElement = Message.createNewRootElement("setCurrentlyBuilding");
-                setCurrentlyBuildingElement.setAttribute("colony", colony.getID());
+                setCurrentlyBuildingElement.setAttribute("colony", colony.getId());
                 setCurrentlyBuildingElement.setAttribute("type", Integer.toString(buildable));
 
                 try {
@@ -1165,8 +1233,8 @@ public class AIColony extends AIObject {
      * @return The same ID as the <code>Colony</code> this
      *         <code>AIColony</code> stores AI-specific information for.
      */
-    public String getID() {
-        return colony.getID();
+    public String getId() {
+        return colony.getId();
     }
 
     /**
@@ -1179,7 +1247,7 @@ public class AIColony extends AIObject {
     protected void toXMLImpl(XMLStreamWriter out) throws XMLStreamException {
         out.writeStartElement(getXMLElementTagName());
 
-        out.writeAttribute("ID", getID());
+        out.writeAttribute("ID", getId());
 
         Iterator<AIGoods> aiGoodsIterator = aiGoods.iterator();
         while (aiGoodsIterator.hasNext()) {
@@ -1188,12 +1256,12 @@ public class AIColony extends AIObject {
                 logger.warning("ag == null");
                 continue;
             }
-            if (ag.getID() == null) {
-                logger.warning("ag.getID() == null");
+            if (ag.getId() == null) {
+                logger.warning("ag.getId() == null");
                 continue;
             }
             out.writeStartElement(AIGoods.getXMLElementTagName() + "ListElement");
-            out.writeAttribute("ID", ag.getID());
+            out.writeAttribute("ID", ag.getId());
             out.writeEndElement();
         }
 
@@ -1211,7 +1279,7 @@ public class AIColony extends AIObject {
                 logger.warning("Unknown type of wish.");
                 continue;
             }
-            out.writeAttribute("ID", w.getID());
+            out.writeAttribute("ID", w.getId());
             out.writeEndElement();
         }
 
@@ -1219,7 +1287,7 @@ public class AIColony extends AIObject {
         while (tileImprovementIterator.hasNext()) {
             TileImprovement ti = tileImprovementIterator.next();
             out.writeStartElement(TileImprovement.getXMLElementTagName() + "ListElement");
-            out.writeAttribute("ID", ti.getID());
+            out.writeAttribute("ID", ti.getId());
             out.writeEndElement();
         }
 
