@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 
 package net.sf.freecol.server.ai;
 
@@ -46,9 +65,6 @@ import org.xml.sax.SAXException;
 public class AIMain implements FreeColGameObjectListener {
     private static final Logger logger = Logger.getLogger(AIMain.class.getName());
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2219 $";
 
     private FreeColServer freeColServer;
     private int nextID = 1;
@@ -137,7 +153,7 @@ public class AIMain implements FreeColGameObjectListener {
         boolean ok = true;
         for (AIObject ao : aiObjects.values()) {
             if (ao.isUninitialized()) {
-                logger.warning("Uninitialized object: " + ao.getID() + " (" + ao.getClass() + ")");
+                logger.warning("Uninitialized object: " + ao.getId() + " (" + ao.getClass() + ")");
                 ok = false;
             }
         }
@@ -145,8 +161,8 @@ public class AIMain implements FreeColGameObjectListener {
         while (fit.hasNext()) {
             FreeColGameObject f = fit.next();
             if ((f instanceof Unit || f instanceof Player || f instanceof Colony)
-                    && !aiObjects.containsKey(f.getID())) {
-                logger.warning("Missing AIObject for: " + f.getID());
+                    && !aiObjects.containsKey(f.getId())) {
+                logger.warning("Missing AIObject for: " + f.getId());
                 ok = false;
             }
         }
@@ -202,7 +218,7 @@ public class AIMain implements FreeColGameObjectListener {
         while (i.hasNext()) {
             FreeColGameObject fcgo = i.next();
             if (overwrite || getAIObject(fcgo) == null) {
-                setFreeColGameObject(fcgo.getID(), fcgo);
+                setFreeColGameObject(fcgo.getId(), fcgo);
             }
         }
     }
@@ -218,7 +234,7 @@ public class AIMain implements FreeColGameObjectListener {
     * @return The <code>AIObject</code>.
     */
     public AIObject getAIObject(FreeColGameObject fcgo) {
-        return getAIObject(fcgo.getID());
+        return getAIObject(fcgo.getId());
     }
 
 
@@ -280,7 +296,7 @@ public class AIMain implements FreeColGameObjectListener {
         AIObject ao = getAIObject(source);
         if (ao != null) {
             ao.dispose();
-            setFreeColGameObject(source.getID(), source);
+            setFreeColGameObject(source.getId(), source);
         }
     }
 
@@ -293,14 +309,14 @@ public class AIMain implements FreeColGameObjectListener {
     * @param freeColGameObject The <code>FreeColGameObject</code> to add.
     * @see AIObject
     * @see FreeColGameObject
-    * @see FreeColGameObject#getID
+    * @see FreeColGameObject#getId
     */
     public void setFreeColGameObject(String id, FreeColGameObject freeColGameObject) {
         if (aiObjects.containsKey(id)) {
             return;
         }
-        if (!id.equals(freeColGameObject.getID())) {
-            throw new IllegalArgumentException("!id.equals(freeColGameObject.getID())");
+        if (!id.equals(freeColGameObject.getId())) {
+            throw new IllegalArgumentException("!id.equals(freeColGameObject.getId())");
         }
         if (freeColGameObject instanceof Unit) {
             new AIUnit(this, (Unit) freeColGameObject);
@@ -425,10 +441,10 @@ public class AIMain implements FreeColGameObjectListener {
 
             try {
                 if (!(aio instanceof Wish) || ((Wish) aio).shouldBeStored()) {
-                    if (aio.getID() != null) {
+                    if (aio.getId() != null) {
                         aio.toXML(out);
                     } else {
-                        logger.warning("aio.getID() == null, for: " + aio.getClass().getName());
+                        logger.warning("aio.getId() == null, for: " + aio.getClass().getName());
                     }
                 }
             } catch (Exception e) {
