@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.server.ai;
 
 import java.io.IOException;
@@ -74,11 +93,8 @@ import org.w3c.dom.Element;
 public class AIPlayer extends AIObject {
     private static final Logger logger = Logger.getLogger(AIPlayer.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2615 $";
 
     private static final int MAX_DISTANCE_TO_BRING_GIFT = 5;
 
@@ -120,7 +136,7 @@ public class AIPlayer extends AIObject {
      *            <code>AIPlayer</code>.
      */
     public AIPlayer(AIMain aiMain, ServerPlayer player) {
-        super(aiMain, player.getID());
+        super(aiMain, player.getId());
         this.player = player;
     }
 
@@ -282,7 +298,7 @@ public class AIPlayer extends AIObject {
         
         for (Player p : dominions) {
             Element giveIndependenceElement = Message.createNewRootElement("giveIndependence");
-            giveIndependenceElement.setAttribute("player", p.getID());
+            giveIndependenceElement.setAttribute("player", p.getId());
             sendAndWaitSafely(giveIndependenceElement);
         }
     }
@@ -293,6 +309,9 @@ public class AIPlayer extends AIObject {
     private void cheat() {
         logger.finest("Entering method cheat");
         // TODO-AI-CHEATING: REMOVE WHEN THE AI IS GOOD ENOUGH:
+        for (int typeOfGoods = 0; typeOfGoods < Goods.NUMBER_OF_TYPES; typeOfGoods++) {
+            player.resetArrears(typeOfGoods);
+        }
         if (getAIMain().getFreeColServer().isSingleplayer() && player.isEuropean() && !player.isREF() && player.isAI()
                 && player.getRebellionState() == Player.REBELLION_PRE_WAR) {
             if (getRandom().nextInt(10) == 1) {
@@ -311,15 +330,15 @@ public class AIPlayer extends AIObject {
                 }
                 if (unit != null) {
                     Element clearSpecialityElement = Message.createNewRootElement("clearSpeciality");
-                    clearSpecialityElement.setAttribute("unit", unit.getID());
+                    clearSpecialityElement.setAttribute("unit", unit.getId());
                     sendAndWaitSafely(clearSpecialityElement);
                     Element equipMusketsElement = Message.createNewRootElement("equipunit");
-                    equipMusketsElement.setAttribute("unit", unit.getID());
+                    equipMusketsElement.setAttribute("unit", unit.getId());
                     equipMusketsElement.setAttribute("type", Integer.toString(Goods.MUSKETS));
                     equipMusketsElement.setAttribute("amount", Integer.toString(50));
                     sendAndWaitSafely(equipMusketsElement);
                     Element equipHorsesElement = Message.createNewRootElement("equipunit");
-                    equipHorsesElement.setAttribute("unit", unit.getID());
+                    equipHorsesElement.setAttribute("unit", unit.getId());
                     equipHorsesElement.setAttribute("type", Integer.toString(Goods.HORSES));
                     equipHorsesElement.setAttribute("amount", Integer.toString(50));
                     sendAndWaitSafely(equipHorsesElement);
@@ -759,26 +778,26 @@ public class AIPlayer extends AIObject {
                     if (!u.isArmed() && u.canBeArmed()) {
                         recruitCount--;
                         Element equipUnitElement = Message.createNewRootElement("equipunit");
-                        equipUnitElement.setAttribute("unit", u.getID());
+                        equipUnitElement.setAttribute("unit", u.getId());
                         equipUnitElement.setAttribute("type", Integer.toString(Goods.MUSKETS));
                         equipUnitElement.setAttribute("amount", "50");
                         u.setArmed(true);
                         sendAndWaitSafely(equipUnitElement);
                         Element putOutsideColonyElement = Message.createNewRootElement("putOutsideColony");
-                        putOutsideColonyElement.setAttribute("unit", u.getID());
+                        putOutsideColonyElement.setAttribute("unit", u.getId());
                         u.putOutsideColony();
                         sendAndWaitSafely(putOutsideColonyElement);
                         // Check if the unit can fortify before sending the order
                         if (u.checkSetState(Unit.FORTIFYING)) {
                             Element changeStateElement = Message.createNewRootElement("changeState");
-                            changeStateElement.setAttribute("unit", u.getID());
+                            changeStateElement.setAttribute("unit", u.getId());
                             changeStateElement.setAttribute("state", Integer.toString(Unit.FORTIFYING));
                             sendAndWaitSafely(changeStateElement);
                         }
                         olddefenders++;
                         if (!u.isMounted() && u.canBeMounted()) {
                             equipUnitElement = Message.createNewRootElement("equipunit");
-                            equipUnitElement.setAttribute("unit", u.getID());
+                            equipUnitElement.setAttribute("unit", u.getId());
                             equipUnitElement.setAttribute("type", Integer.toString(Goods.HORSES));
                             equipUnitElement.setAttribute("amount", "50");
                             sendAndWaitSafely(equipUnitElement);
@@ -1326,7 +1345,7 @@ public class AIPlayer extends AIObject {
             value -= turns * 10;
             return Math.max(0, value);
         } else {
-            return 0;
+            return Integer.MIN_VALUE;
         }
     }
 
@@ -1593,7 +1612,7 @@ public class AIPlayer extends AIObject {
                 }
                 int result = o2.getTransportPriority() - o1.getTransportPriority();
                 if (result == 0) {
-                    result = o1.getID().compareTo(o2.getID());
+                    result = o1.getId().compareTo(o2.getId());
                 }
                 return result;
             }
@@ -1714,7 +1733,7 @@ public class AIPlayer extends AIObject {
             switch (foundingFathers[i]) {
             case FoundingFather.ADAM_SMITH:
                 if (strategy == STRATEGY_TRADE) {
-                    value = 10;
+                    value = 11;
                 } else {
                     value = 5;
                 }
@@ -1734,11 +1753,17 @@ public class AIPlayer extends AIObject {
                 }
                 break;
             case FoundingFather.PETER_STUYVESANT:
-                if (strategy == STRATEGY_TRADE) {
+                /*if (strategy == STRATEGY_TRADE) {
                     value = 8;
                 } else {
                     value = 4;
-                }
+                }*/
+                /*
+                 * The goods transportation code is currently
+                 * really bad. Therefor: max priority for this
+                 * founding father.
+                 */
+                value = 12;
                 break;
             case FoundingFather.JAN_DE_WITT:
                 if (strategy == STRATEGY_TRADE) {
@@ -1768,7 +1793,7 @@ public class AIPlayer extends AIObject {
                 break;
             case FoundingFather.HERNAN_CORTES:
                 if (strategy == STRATEGY_CONQUEST) {
-                    value = 10;
+                    value = 9;
                 } else if (strategy == STRATEGY_COOPERATION) {
                     value = 1;
                 } else {
@@ -1776,7 +1801,11 @@ public class AIPlayer extends AIObject {
                 }
                 break;
             case FoundingFather.GEORGE_WASHINGTON:
-                value = 5;
+                if (strategy == STRATEGY_CONQUEST) {
+                    value = 10;
+                } else {
+                    value = 5;
+                }
                 break;
             case FoundingFather.PAUL_REVERE:
                 value = 2;
@@ -1871,8 +1900,8 @@ public class AIPlayer extends AIObject {
     public int tradeProposition(Unit unit, Settlement settlement, Goods goods, int gold) {
         logger.finest("Entering method tradeProposition");
         if (settlement instanceof IndianSettlement) {
-            String goldKey = "tradeGold#" + goods.getType() + "#" + goods.getAmount() + "#" + unit.getID();
-            String hagglingKey = "tradeHaggling#" + unit.getID();
+            String goldKey = "tradeGold#" + goods.getType() + "#" + goods.getAmount() + "#" + unit.getId();
+            String hagglingKey = "tradeHaggling#" + unit.getId();
             int price;
             if (sessionRegister.containsKey(goldKey)) {
                 price = sessionRegister.get(goldKey).intValue();
@@ -2005,12 +2034,12 @@ public class AIPlayer extends AIObject {
             Iterator<Unit> unitsIterator = player.getUnitIterator();
             while (unitsIterator.hasNext()) {
                 Unit theUnit = unitsIterator.next();
-                AIUnit a = (AIUnit) getAIMain().getAIObject(theUnit.getID());
+                AIUnit a = (AIUnit) getAIMain().getAIObject(theUnit.getId());
                 if (a != null) {
                     au.add(a);
                 } else {
-                    logger.warning("Could not find the AIUnit for: " + theUnit + " (" + theUnit.getID() + ") - "
-                            + (getGame().getFreeColGameObject(theUnit.getID()) != null));
+                    logger.warning("Could not find the AIUnit for: " + theUnit + " (" + theUnit.getId() + ") - "
+                            + (getGame().getFreeColGameObject(theUnit.getId()) != null));
                 }
             }
             aiUnits = au;
@@ -2029,7 +2058,7 @@ public class AIPlayer extends AIObject {
         Iterator<Colony> colonyIterator = player.getColonyIterator();
         while (colonyIterator.hasNext()) {
             Colony colony = colonyIterator.next();
-            AIColony a = (AIColony) getAIMain().getAIObject(colony.getID());
+            AIColony a = (AIColony) getAIMain().getAIObject(colony.getId());
             if (a != null) {
                 ac.add(a);
             } else {
@@ -2092,8 +2121,8 @@ public class AIPlayer extends AIObject {
      * @return The ID.
      */
     @Override
-    public String getID() {
-        return player.getID();
+    public String getId() {
+        return player.getId();
     }
 
     /**
@@ -2106,7 +2135,7 @@ public class AIPlayer extends AIObject {
     @Override
     protected void toXMLImpl(XMLStreamWriter out) throws XMLStreamException {
         out.writeStartElement(getXMLElementTagName());
-        out.writeAttribute("ID", getID());
+        out.writeAttribute("ID", getId());
         out.writeEndElement();
     }
 
@@ -2141,7 +2170,7 @@ public class AIPlayer extends AIObject {
      */
     public void registerSellGoods(Goods goods) {
         String goldKey = "tradeGold#" + goods.getType() + "#" + goods.getAmount()
-            + "#" + goods.getLocation().getID();
+            + "#" + goods.getLocation().getId();
         sessionRegister.put(goldKey, null);
     }
 
@@ -2159,8 +2188,8 @@ public class AIPlayer extends AIObject {
         logger.finest("Entering method tradeProposition");
         IndianSettlement settlement = (IndianSettlement) goods.getLocation();
         String goldKey = "tradeGold#" + goods.getType() + "#" + goods.getAmount()
-            + "#" + settlement.getID();
-        String hagglingKey = "tradeHaggling#" + unit.getID();
+            + "#" + settlement.getId();
+        String hagglingKey = "tradeHaggling#" + unit.getId();
         
         Integer registered = sessionRegister.get(goldKey);
         if (registered == null) {
