@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.server.ai.mission;
 
 import java.io.IOException;
@@ -45,11 +64,8 @@ import org.w3c.dom.Element;
 public class TransportMission extends Mission {
     private static final Logger logger = Logger.getLogger(TransportMission.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2272 $";
 
     private static final String ELEMENT_TRANSPORTABLE = "transportable";
 
@@ -115,6 +131,21 @@ public class TransportMission extends Mission {
             AIUnit aiUnit = (AIUnit) getAIMain().getAIObject(u);
             addToTransportList(aiUnit);
         }
+        
+        // Remove items that are no longer on the transport list:
+        List<Transportable> ts = new LinkedList<Transportable>();
+        for (Transportable t : new LinkedList<Transportable>(transportList)) {
+            if (ts.contains(t) || isCarrying(t)) {
+                if (t.getTransportDestination() == null) {
+                    removeFromTransportList(t);
+                }
+            } else {
+                if (t.getTransportSource() == null) {
+                    removeFromTransportList(t);
+                }
+            }
+            ts.add(t);
+        }
     }
 
     /**
@@ -340,7 +371,7 @@ public class TransportMission extends Mission {
                 // Move back to america:
                 if (carrier.getOwner().getGold() < MINIMUM_GOLD_TO_STAY_IN_EUROPE || transportList.size() > 0) {
                     Element moveToAmericaElement = Message.createNewRootElement("moveToAmerica");
-                    moveToAmericaElement.setAttribute("unit", carrier.getID());
+                    moveToAmericaElement.setAttribute("unit", carrier.getId());
                     try {
                         connection.sendAndWait(moveToAmericaElement);
                     } catch (IOException e) {
@@ -397,7 +428,7 @@ public class TransportMission extends Mission {
                     // carrier.getTile());
                     if (carrier.getMoveType(r) == Unit.MOVE_HIGH_SEAS && moveToEurope) {
                         Element moveToEuropeElement = Message.createNewRootElement("moveToEurope");
-                        moveToEuropeElement.setAttribute("unit", carrier.getID());
+                        moveToEuropeElement.setAttribute("unit", carrier.getId());
                         try {
                             connection.sendAndWait(moveToEuropeElement);
                         } catch (IOException e) {
@@ -415,7 +446,7 @@ public class TransportMission extends Mission {
                 transportListChanged = restockCargoAtDestination(connection);
             } else if (moveToEurope && carrier.canMoveToEurope()) {
                 Element moveToEuropeElement = Message.createNewRootElement("moveToEurope");
-                moveToEuropeElement.setAttribute("unit", carrier.getID());
+                moveToEuropeElement.setAttribute("unit", carrier.getId());
                 try {
                     connection.sendAndWait(moveToEuropeElement);
                 } catch (IOException e) {
@@ -437,7 +468,7 @@ public class TransportMission extends Mission {
      * @param connection The <code>Connection</code> to the server.
      */
     private void buyCargo(Connection connection) {
-        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getID());
+        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getId());
 
         if (!(getUnit().getLocation() instanceof Europe)) {
             throw new IllegalStateException("Carrier not in Europe");
@@ -475,7 +506,7 @@ public class TransportMission extends Mission {
                     && t.getTransportDestination().getTile().getColony() != null
                     && t.getTransportDestination().getTile().getColony().getOwner() == getUnit().getOwner()) {
                 AIColony ac = (AIColony) getAIMain().getAIObject(
-                        t.getTransportDestination().getTile().getColony().getID());
+                        t.getTransportDestination().getTile().getColony().getId());
                 aiColonies.add(ac);
             }
         }
@@ -484,7 +515,7 @@ public class TransportMission extends Mission {
          * Add the colony containing the wish with the highest value to the
          * "aiColonies"-list:
          */
-        Iterator<Wish> highValueWishIterator = ((AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getID()))
+        Iterator<Wish> highValueWishIterator = ((AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getId()))
                 .getWishIterator();
         while (highValueWishIterator.hasNext()) {
             Wish w = highValueWishIterator.next();
@@ -574,13 +605,13 @@ public class TransportMission extends Mission {
      * @return The goods.
      */
     public AIGoods buyGoodsInEurope(Connection connection, int type, int amount, Location destination) {
-        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getID());
+        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getId());
         Player player = aiPlayer.getPlayer();
         Market market = player.getMarket();
 
         if (player.getGold() >= market.getBidPrice(type, amount)) {
             Element buyGoodsElement = Message.createNewRootElement("buyGoods");
-            buyGoodsElement.setAttribute("carrier", getUnit().getID());
+            buyGoodsElement.setAttribute("carrier", getUnit().getId());
             buyGoodsElement.setAttribute("type", Integer.toString(type));
             buyGoodsElement.setAttribute("amount", Integer.toString(amount));
             try {
@@ -621,7 +652,7 @@ public class TransportMission extends Mission {
      * @return The <code>AIUnit</code>.
      */
     private AIUnit getUnitInEurope(Connection connection, int unitType) {
-        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getID());
+        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getId());
         Player player = aiPlayer.getPlayer();
         Europe europe = player.getEurope();
 
@@ -634,7 +665,7 @@ public class TransportMission extends Mission {
         while (ui.hasNext()) {
             Unit u = ui.next();
             if (unitType == -1 || unitType == u.getType()) {
-                return (AIUnit) getAIMain().getAIObject(u.getID());
+                return (AIUnit) getAIMain().getAIObject(u.getId());
             }
         }
 
@@ -691,7 +722,7 @@ public class TransportMission extends Mission {
      * @return The <code>AIUnit</code>.
      */
     private AIUnit getCheapestUnitInEurope(Connection connection) {
-        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getID());
+        AIPlayer aiPlayer = (AIPlayer) getAIMain().getAIObject(getUnit().getOwner().getId());
         Player player = aiPlayer.getPlayer();
         Europe europe = player.getEurope();
 
@@ -704,7 +735,7 @@ public class TransportMission extends Mission {
         while (ui.hasNext()) {
             Unit u = ui.next();
             if (!u.isCarrier() && ((AIUnit) getAIMain().getAIObject(u)).getTransport() == null) {
-                return (AIUnit) getAIMain().getAIObject(u.getID());
+                return (AIUnit) getAIMain().getAIObject(u.getId());
             }
         }
 
@@ -895,7 +926,7 @@ public class TransportMission extends Mission {
                             && carrier.getState() != Unit.TO_EUROPE && carrier.getState() != Unit.TO_AMERICA) {
                         if (u.getLocation() instanceof Europe || u.getColony() != null) {
                             Element leaveShipElement = Message.createNewRootElement("leaveShip");
-                            leaveShipElement.setAttribute("unit", u.getID());
+                            leaveShipElement.setAttribute("unit", u.getId());
                             try {
                                 connection.sendAndWait(leaveShipElement);
                             } catch (IOException e) {
@@ -1021,8 +1052,8 @@ public class TransportMission extends Mission {
                 if (u.getTile() == carrier.getTile() && carrier.getState() != Unit.TO_EUROPE
                         && carrier.getState() != Unit.TO_AMERICA) {
                     Element boardShipElement = Message.createNewRootElement("boardShip");
-                    boardShipElement.setAttribute("unit", u.getID());
-                    boardShipElement.setAttribute("carrier", carrier.getID());
+                    boardShipElement.setAttribute("unit", u.getId());
+                    boardShipElement.setAttribute("carrier", carrier.getId());
                     try {
                         connection.sendAndWait(boardShipElement);
                         tli.remove();
@@ -1037,7 +1068,7 @@ public class TransportMission extends Mission {
                         && carrier.getState() != Unit.TO_AMERICA) {
                     if (carrier.getLocation() instanceof Europe) {
                         Element buyGoodsElement = Message.createNewRootElement("buyGoods");
-                        buyGoodsElement.setAttribute("carrier", carrier.getID());
+                        buyGoodsElement.setAttribute("carrier", carrier.getId());
                         buyGoodsElement.setAttribute("type", Integer.toString(ag.getGoods().getType()));
                         buyGoodsElement.setAttribute("amount", Integer.toString(ag.getGoods().getAmount()));
                         try {
@@ -1050,7 +1081,7 @@ public class TransportMission extends Mission {
                         ag.setGoods(new Goods(getGame(), carrier, ag.getGoods().getType(), ag.getGoods().getAmount()));
                     } else {
                         Element loadCargoElement = Message.createNewRootElement("loadCargo");
-                        loadCargoElement.setAttribute("carrier", carrier.getID());
+                        loadCargoElement.setAttribute("carrier", carrier.getId());
                         loadCargoElement.appendChild(ag.getGoods().toXMLElement(carrier.getOwner(),
                                 loadCargoElement.getOwnerDocument()));
 
@@ -1122,13 +1153,13 @@ public class TransportMission extends Mission {
     protected void toXMLImpl(XMLStreamWriter out) throws XMLStreamException {
         out.writeStartElement(getXMLElementTagName());
 
-        out.writeAttribute("unit", getUnit().getID());
+        out.writeAttribute("unit", getUnit().getId());
 
         Iterator<Transportable> tli = transportList.iterator();
         while (tli.hasNext()) {
             Transportable t = tli.next();
             out.writeStartElement(ELEMENT_TRANSPORTABLE);
-            out.writeAttribute("ID", ((AIObject) t).getID());
+            out.writeAttribute("ID", ((AIObject) t).getId());
             out.writeEndElement();
         }
         out.writeEndElement();
