@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.server.control;
 
 import java.io.IOException;
@@ -10,6 +29,8 @@ import net.sf.freecol.common.model.Colony;
 import net.sf.freecol.common.model.FoundingFather;
 import net.sf.freecol.common.model.GameOptions;
 import net.sf.freecol.common.model.Goods;
+import net.sf.freecol.common.model.IndianSettlement;
+import net.sf.freecol.common.model.Location;
 import net.sf.freecol.common.model.Map;
 import net.sf.freecol.common.model.Market;
 import net.sf.freecol.common.model.Monarch;
@@ -30,11 +51,8 @@ import org.w3c.dom.Element;
 public final class InGameController extends Controller {
     private static Logger logger = Logger.getLogger(InGameController.class.getName());
 
-    public static final String COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
 
-    public static final String LICENSE = "http://www.gnu.org/licenses/gpl.html";
 
-    public static final String REVISION = "$Revision: 2569 $";
 
     public int debugOnlyAITurns = 0;
 
@@ -82,7 +100,7 @@ public final class InGameController extends Controller {
         Player winner = checkForWinner();
         if (winner != null && (!freeColServer.isSingleplayer() || !winner.isAI())) {
             Element gameEndedElement = Message.createNewRootElement("gameEnded");
-            gameEndedElement.setAttribute("winner", winner.getID());
+            gameEndedElement.setAttribute("winner", winner.getId());
             freeColServer.getServer().sendToAll(gameEndedElement, null);
             return;
         }
@@ -129,7 +147,7 @@ public final class InGameController extends Controller {
             if (checkForDeath(newPlayer)) {
                 newPlayer.setDead(true);
                 Element setDeadElement = Message.createNewRootElement("setDead");
-                setDeadElement.setAttribute("player", newPlayer.getID());
+                setDeadElement.setAttribute("player", newPlayer.getId());
                 freeColServer.getServer().sendToAll(setDeadElement, null);
                 return nextPlayer();
             }
@@ -160,7 +178,7 @@ public final class InGameController extends Controller {
         }
         
         Element setCurrentPlayerElement = Message.createNewRootElement("setCurrentPlayer");
-        setCurrentPlayerElement.setAttribute("player", newPlayer.getID());
+        setCurrentPlayerElement.setAttribute("player", newPlayer.getId());
         freeColServer.getServer().sendToAll(setCurrentPlayerElement, null);
         
         return newPlayer;
@@ -331,22 +349,49 @@ public final class InGameController extends Controller {
              */
             return false;
         }
-        
-        Map map = getGame().getMap();
 
         // Quick check to avoid long processing time:
         if (!player.getSettlements().isEmpty()) {
             return false;
         }
 
+        Map map = getGame().getMap();
+        
         Iterator<Position> tileIterator = map.getWholeMapIterator();
         while (tileIterator.hasNext()) {
             Tile t = map.getTile(tileIterator.next());
-            if (t != null
-                    && ((t.getFirstUnit() != null && t.getFirstUnit().getOwner().equals(player)) || t.getSettlement() != null
-                            && t.getSettlement().getOwner().equals(player))) {
-                return false;
+            
+            Unit firstUnit = t.getFirstUnit();
+            
+            if (t == null || firstUnit == null){
+            		continue;
             }
+            
+            // Tile occupied by enemy forces
+            if(!firstUnit.getOwner().equals(player)){
+            	continue;
+            }
+            
+            // Verify if there are any naval units with:
+            // - offensive capability, or 
+            // - carrying units and/or goods
+            if(!t.isLand()){
+            	Iterator<Unit> unitList = t.getUnitIterator();
+            	while(unitList.hasNext()){
+            		Unit navalUnit = unitList.next();
+            		if(navalUnit.isOffensiveUnit()){
+            			return false;
+            		}
+            		if(navalUnit.getGoodsCount() > 0 ||
+            		   navalUnit.getUnitCount() > 0){
+            			return false;
+            		}
+            	}
+            	continue;
+            }
+            
+            // Unit available, do not end game
+            return false;
         }
         
         /*
@@ -354,31 +399,88 @@ public final class InGameController extends Controller {
          * settlements on the map.
          */
         
-        if (player.isEuropean()) {
-            /*
-             * if (getGame().getTurn().getNumber() > 20 ||
-             * player.getEurope().getFirstUnit() == null && player.getGold() <
-             * 600 && player.getGold() < player.getRecruitPrice()) {
-             * 
-             */
-            if (getGame().getTurn().getNumber() > 20) {
-                return true;
-            } else if (player.getEurope() == null) {
-                return true;
-            } else if (player.getGold() < 1000) {
-                Iterator<Unit> unitIterator = player.getEurope().getUnitIterator();
-                while (unitIterator.hasNext()) {
-                    if (unitIterator.next().isCarrier()) {
-                        return false;
-                    }
-                }
-                return true;
-            } else {
-                return false;
-            }
-        } else {
-            return true;
+        /*
+         *  No Europe, no reenforcements
+         */
+        if (!player.isEuropean() || player.getEurope() == null) {
+        	return true;
         }
+        
+        // After 20 turns, no presence in New World means endgame
+        if (getGame().getTurn().getNumber() > 20) {
+        	return true;
+        }
+        
+        /*
+         * Check if player has colonists and carrier to transport them to New World
+         */
+        boolean hasCarrier = false;
+        boolean hasColonistsWaiting = false;
+        
+        Iterator<Unit> unitIterator = player.getEurope().getUnitIterator();
+    	while (unitIterator.hasNext()) {
+    		Unit unit = unitIterator.next();
+    		if (unit.isCarrier()) {
+    			/*
+    			 * The carrier has units 
+    			 *or goods that can be sold
+    			 */
+    			if(unit.getGoodsCount() > 0){
+    				return false;
+    			}
+    			
+    			hasCarrier = true;
+    			continue;
+    		}
+    		if (unit.isColonist()){
+    			hasColonistsWaiting = true;
+    			continue;
+    		}
+    	}
+        
+        int goldNeeded = 0;
+        
+        /*
+    	 * No carrier, check if has gold to buy one
+    	 */
+    	if(!hasCarrier){
+    		/*
+    		 * We are assuming that the caravel
+    		 *is the cheapest naval unit, like in Colonization
+    		 */
+    		goldNeeded += Unit.getPrice(Unit.CARAVEL);
+    		
+    		if(goldNeeded > player.getGold()){
+    			return true;
+    		}
+    	}
+    	
+    	/*
+    	 * No colonists, check if has gold to train 
+    	 *or recruit one
+    	 */
+    	
+    	if(!hasColonistsWaiting){
+    		int goldToRecruit =  player.getEurope().getRecruitPrice();
+    		
+    		/*
+    		 * We are assuming that the expert fur trapper
+    		 *is the cheapest trainable colonist unit, like in COlonization
+    		 */
+    		int goldToTrain = Unit.getPrice(Unit.EXPERT_FUR_TRAPPER);
+    		
+    		goldNeeded += Math.min(goldToTrain, goldToRecruit);
+    		
+    		if(goldNeeded > player.getGold()){
+    			return true;
+    		}
+    	}
+    	
+    	/*
+    	 * Has carrier and colonists waiting, or
+    	 *enough gold to buy them
+    	 */
+    	return false;
     }
 
     /**
@@ -399,9 +501,9 @@ public final class InGameController extends Controller {
                     switch (action) {
                     case Monarch.RAISE_TAX:
                         int oldTax = nextPlayer.getTax();
-                        int newTax = monarch.getNewTax();
-                        if (newTax > 100) {
-                            logger.warning("Tax rate exceeds 100 percent.");
+                        int newTax = monarch.getNewTax(Monarch.RAISE_TAX);
+                        if (newTax < 0 || newTax > 100) {
+                            logger.warning("New tax invalid=" + String.valueOf(newTax));
                             return;
                         }
                         Goods goods = nextPlayer.getMostValuableGoods();
@@ -436,6 +538,20 @@ public final class InGameController extends Controller {
                             logger.warning("Could not send message to: " + nextPlayer.getName());
                         }
                         break;
+                    case Monarch.LOWER_TAX:
+                        int taxLowered = monarch.getNewTax(Monarch.LOWER_TAX);
+                        if (taxLowered < 0 || taxLowered > 100) {
+                            logger.warning("New tax invalid=" + String.valueOf(taxLowered));
+                            return;
+                        }
+                        monarchActionElement.setAttribute("amount", String.valueOf(taxLowered));
+                        try {
+                            nextPlayer.setTax(taxLowered); // to avoid cheating
+                            nextPlayer.getConnection().send(monarchActionElement); 
+                        } catch (IOException e) {
+                            logger.warning("Could not send message to: " + nextPlayer.getName());
+                        }
+                        break;
                     case Monarch.ADD_TO_REF:
                         int[] addition = monarch.addToREF();
                         Element additionElement = monarchActionElement.getOwnerDocument().createElement("addition");
@@ -539,22 +655,25 @@ public final class InGameController extends Controller {
             }
         }
     }
+    
+    public boolean createMission(IndianSettlement settlement,Unit missionary){
+    	settlement.setMissionary(missionary);
+    	
+    	//TODO: make possibility of indians refusing the mission 
+    	return true;
+    }
 
     private void bombardEnemyShips(ServerPlayer currentPlayer) {
-        logger.finest("Entering method bombardEnemyShips.");
         Map map = getFreeColServer().getGame().getMap();
         for (Settlement settlement : currentPlayer.getSettlements()) {
             Colony colony = (Colony) settlement;
-            logger.finest("Colony is " + colony.getName());
-            Building stockade = colony.getBuilding(Building.STOCKADE);
-            if (stockade.getLevel() > Building.HOUSE && !colony.isLandLocked()) {
-                logger.finest("Colony has harbour and fort.");
-                float attackPower = colony.getBombardingPower();
-                if (attackPower <= 0) {
-                    continue;
-                }
+            if (colony.canBombardEnemyShip()) {
+            	float attackPower = colony.getBombardingPower();
+                
                 Unit attacker = colony.getBombardingAttacker();
-                logger.finest("Colony has attack power " + attackPower);
+                
+                Building stockade = colony.getBuilding(Building.STOCKADE);
+                
                 Position colonyPosition = colony.getTile().getPosition();
                 for (int direction = 0; direction < Map.NUMBER_OF_DIRECTIONS; direction++) {
                     Tile tile = map.getTile(Map.getAdjacent(colonyPosition, direction));
@@ -563,10 +682,13 @@ public final class InGameController extends Controller {
                         while (unitIterator.hasNext()) {
                             Unit unit = unitIterator.next();
                             Player player = unit.getOwner();
-                            if (player != currentPlayer
-                                    && (currentPlayer.getStance(player) == Player.WAR || unit.getType() == Unit.PRIVATEER)) {
-                                logger.finest("Found enemy unit " + unit.getOwner().getNationAsString() + " "
-                                        + unit.getName());
+                            
+                            // skip over own units
+                            if(player == currentPlayer){
+                            	continue;
+                            }
+                            
+                            if (currentPlayer.getStance(player) == Player.WAR || unit.getType() == Unit.PRIVATEER) {                       
                                 // generate bombardment result
                                 float totalProbability = attackPower + unit.getDefensePower(attacker);
                                 int result;
@@ -582,7 +704,19 @@ public final class InGameController extends Controller {
                                 } else {
                                     result = Unit.ATTACK_EVADES;
                                 }
-
+                                Location repairLocation = null;
+                                
+                                // ship damaged, send it to a repair location
+                                if(result == Unit.ATTACK_WIN){
+                                	repairLocation = unit.getOwner().getRepairLocation(unit);
+                                	unit.shipDamaged(colony,repairLocation);
+                                }
+                                
+                                // ship sunk
+                                if(result == Unit.ATTACK_GREAT_WIN){
+                                	unit.shipSunk(colony, stockade);
+                                }
+                                
                                 // Inform the players (other then the player
                                 // attacking) about the attack:
                                 int plunderGold = -1;
@@ -599,19 +733,23 @@ public final class InGameController extends Controller {
                                     if (unit.isVisibleTo(enemyPlayer)) {
                                         opponentAttackElement.setAttribute("direction", Integer.toString(direction));
                                         opponentAttackElement.setAttribute("result", Integer.toString(result));
-                                        opponentAttackElement
-                                                .setAttribute("plunderGold", Integer.toString(plunderGold));
-                                        opponentAttackElement.setAttribute("colony", colony.getID());
-                                        opponentAttackElement.setAttribute("building", stockade.getID());
-                                        opponentAttackElement.setAttribute("unit", attacker.getID());
-                                        opponentAttackElement.setAttribute("defender", unit.getID());
-
+                                        opponentAttackElement.setAttribute("plunderGold", Integer.toString(plunderGold));
+                                        opponentAttackElement.setAttribute("colony", colony.getId());
+                                        opponentAttackElement.setAttribute("building", stockade.getName());
+                                        opponentAttackElement.setAttribute("unit", attacker.getId());
+                                        opponentAttackElement.setAttribute("defender", unit.getId());
+                                        
                                         if (!enemyPlayer.canSee(attacker.getTile())) {
                                             opponentAttackElement.setAttribute("update", "tile");
                                             enemyPlayer.setExplored(attacker.getTile());
                                             opponentAttackElement.appendChild(attacker.getTile().toXMLElement(
                                                         enemyPlayer, opponentAttackElement.getOwnerDocument()));
                                         }
+                                        
+                                        // tell defender owner where to send the unit if damaged
+                                        if (enemyPlayer.equals(player) && repairLocation != null){
+                                        	opponentAttackElement.setAttribute("repairIn", repairLocation.getId());
+                                        }
 
                                         try {
                                             enemyPlayer.getConnection().send(opponentAttackElement);
@@ -629,7 +767,7 @@ public final class InGameController extends Controller {
                                  * bombardElement.setAttribute("result",
                                  * Integer.toString(result));
                                  * bombardElement.setAttribute("colony",
-                                 * colony.getID());
+                                 * colony.getId());
                                  * 
                                  * if (!unit.isVisibleTo(player)) {
                                  * bombardElement.appendChild(unit.toXMLElement(player,
