@@ -1,3 +1,22 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.server.generator;
 
 import java.io.File;
@@ -39,9 +58,6 @@ import net.sf.freecol.server.model.ServerPlayer;
 public class MapGenerator {
     private static final Logger logger = Logger.getLogger(MapGenerator.class.getName());
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2475 $";
     
     private final static int NUM_STARTING_LOCATIONS = 4;
 
@@ -521,8 +537,11 @@ public class MapGenerator {
                 continue;
             }
 
-            int y = random.nextInt(height - 20) + 10;
-            int x = width - 1;
+            int x, y;
+            do {
+                x = width - 1;
+                y = random.nextInt(height - 20) + 10;
+            } while (map.getTile(x, y).isLand());
             while (isAShipTooClose(map, y, shipYPos)) {
                 y = random.nextInt(height - 20) + 10;
             }
