@@ -1,15 +1,33 @@
+/**
+ *  Copyright (C) 2002-2007  The FreeCol Team
+ *
+ *  This file is part of FreeCol.
+ *
+ *  FreeCol is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  FreeCol is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with FreeCol.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 package net.sf.freecol.server.generator;
 
 import javax.xml.stream.XMLStreamException;
 import javax.xml.stream.XMLStreamReader;
 
+import net.sf.freecol.client.gui.i18n.Messages;
 import net.sf.freecol.common.option.BooleanOption;
 import net.sf.freecol.common.option.FileOption;
 import net.sf.freecol.common.option.OptionGroup;
 import net.sf.freecol.common.option.OptionMap;
-import net.sf.freecol.common.option.SelectOption;
-
-import net.sf.freecol.client.gui.i18n.Messages;
+import net.sf.freecol.common.option.RangeOption;
 
 import org.w3c.dom.Element;
 
@@ -27,9 +45,6 @@ import org.w3c.dom.Element;
  */
 public class MapGeneratorOptions extends OptionMap {
 
-    public static final String  COPYRIGHT = "Copyright (C) 2003-2005 The FreeCol Team";
-    public static final String  LICENSE = "http://www.gnu.org/licenses/gpl.html";
-    public static final String  REVISION = "$Revision: 2694 $";
 
     /**
      * Option for setting the size of the map.
@@ -266,21 +281,21 @@ public class MapGeneratorOptions extends OptionMap {
             mapSizes[index] = sizes[index] + " (" + getWidth(index) + "x" +
                 getHeight(index) + ")";
         }
-        new SelectOption(MAP_SIZE, landGeneratorGroup, mapSizes, 0, true);
+        new RangeOption(MAP_SIZE, landGeneratorGroup, mapSizes, 0, true);
 
         String[] landMasses = new String[sizes.length];
         for (int index = 0; index < sizes.length; index++) {
             landMasses[index] = sizes[index] + " (" + getLandMass(index) + "%)";
         }
-        new SelectOption(LAND_MASS, landGeneratorGroup, landMasses, 1, true);
+        new RangeOption(LAND_MASS, landGeneratorGroup, landMasses, 1, true);
         add(landGeneratorGroup);
         
         final OptionGroup terrainGeneratorGroup = new OptionGroup("mapGeneratorOptions.terrainGenerator");
-        new SelectOption(RIVER_NUMBER, terrainGeneratorGroup, sizes, 1, true);
-        new SelectOption(MOUNTAIN_NUMBER, terrainGeneratorGroup, sizes, 1, true);
-        new SelectOption(RUMOUR_NUMBER, terrainGeneratorGroup, sizes, 1, true);
-        new SelectOption(FOREST_NUMBER, terrainGeneratorGroup, sizes, 2, true);
-        new SelectOption(BONUS_NUMBER, terrainGeneratorGroup, sizes, 1, true);
+        new RangeOption(RIVER_NUMBER, terrainGeneratorGroup, sizes, 1, true);
+        new RangeOption(MOUNTAIN_NUMBER, terrainGeneratorGroup, sizes, 1, true);
+        new RangeOption(RUMOUR_NUMBER, terrainGeneratorGroup, sizes, 1, true);
+        new RangeOption(FOREST_NUMBER, terrainGeneratorGroup, sizes, 2, true);
+        new RangeOption(BONUS_NUMBER, terrainGeneratorGroup, sizes, 1, true);
         add(terrainGeneratorGroup);
     }
 
